"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import data_room_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class DataRoomStatus(_DataRoomStatus, metaclass=_DataRoomStatusEnumTypeWrapper):
    pass
class _DataRoomStatus:
    V = typing.NewType('V', builtins.int)
class _DataRoomStatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_DataRoomStatus.V], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
    Active = DataRoomStatus.V(0)
    Stopped = DataRoomStatus.V(1)

Active = DataRoomStatus.V(0)
Stopped = DataRoomStatus.V(1)
global___DataRoomStatus = DataRoomStatus


class GcgRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    EXECUTECOMPUTEREQUEST_FIELD_NUMBER: builtins.int
    CREATEDATAROOMREQUEST_FIELD_NUMBER: builtins.int
    PUBLISHDATASETTODATAROOMREQUEST_FIELD_NUMBER: builtins.int
    RETRIEVEDATAROOMREQUEST_FIELD_NUMBER: builtins.int
    RETRIEVEAUDITLOGREQUEST_FIELD_NUMBER: builtins.int
    RETRIEVEDATAROOMSTATUSREQUEST_FIELD_NUMBER: builtins.int
    UPDATEDATAROOMSTATUSREQUEST_FIELD_NUMBER: builtins.int
    RETRIEVEPUBLISHEDDATASETSREQUEST_FIELD_NUMBER: builtins.int
    REMOVEPUBLISHEDDATASETREQUEST_FIELD_NUMBER: builtins.int
    JOBSTATUSREQUEST_FIELD_NUMBER: builtins.int
    GETRESULTSREQUEST_FIELD_NUMBER: builtins.int
    CREATECONFIGURATIONCOMMITREQUEST_FIELD_NUMBER: builtins.int
    EXECUTEDEVELOPMENTCOMPUTEREQUEST_FIELD_NUMBER: builtins.int
    GENERATEMERGEAPPROVALSIGNATUREREQUEST_FIELD_NUMBER: builtins.int
    MERGECONFIGURATIONCOMMITREQUEST_FIELD_NUMBER: builtins.int
    RETRIEVEDATAROOMCONFIGURATIONHISTORYREQUEST_FIELD_NUMBER: builtins.int
    RETRIEVECONFIGURATIONCOMMITAPPROVERSREQUEST_FIELD_NUMBER: builtins.int
    RETRIEVECONFIGURATIONCOMMITREQUEST_FIELD_NUMBER: builtins.int
    @property
    def executeComputeRequest(self) -> global___ExecuteComputeRequest: ...
    @property
    def createDataRoomRequest(self) -> global___CreateDataRoomRequest: ...
    @property
    def publishDatasetToDataRoomRequest(self) -> global___PublishDatasetToDataRoomRequest: ...
    @property
    def retrieveDataRoomRequest(self) -> global___RetrieveDataRoomRequest: ...
    @property
    def retrieveAuditLogRequest(self) -> global___RetrieveAuditLogRequest: ...
    @property
    def retrieveDataRoomStatusRequest(self) -> global___RetrieveDataRoomStatusRequest: ...
    @property
    def updateDataRoomStatusRequest(self) -> global___UpdateDataRoomStatusRequest: ...
    @property
    def retrievePublishedDatasetsRequest(self) -> global___RetrievePublishedDatasetsRequest: ...
    @property
    def removePublishedDatasetRequest(self) -> global___RemovePublishedDatasetRequest: ...
    @property
    def jobStatusRequest(self) -> global___JobStatusRequest: ...
    @property
    def getResultsRequest(self) -> global___GetResultsRequest: ...
    @property
    def createConfigurationCommitRequest(self) -> global___CreateConfigurationCommitRequest: ...
    @property
    def executeDevelopmentComputeRequest(self) -> global___ExecuteDevelopmentComputeRequest: ...
    @property
    def generateMergeApprovalSignatureRequest(self) -> global___GenerateMergeApprovalSignatureRequest: ...
    @property
    def mergeConfigurationCommitRequest(self) -> global___MergeConfigurationCommitRequest: ...
    @property
    def retrieveDataRoomConfigurationHistoryRequest(self) -> global___RetrieveDataRoomConfigurationHistoryRequest: ...
    @property
    def retrieveConfigurationCommitApproversRequest(self) -> global___RetrieveConfigurationCommitApproversRequest: ...
    @property
    def retrieveConfigurationCommitRequest(self) -> global___RetrieveConfigurationCommitRequest: ...
    def __init__(self,
        *,
        executeComputeRequest : typing.Optional[global___ExecuteComputeRequest] = ...,
        createDataRoomRequest : typing.Optional[global___CreateDataRoomRequest] = ...,
        publishDatasetToDataRoomRequest : typing.Optional[global___PublishDatasetToDataRoomRequest] = ...,
        retrieveDataRoomRequest : typing.Optional[global___RetrieveDataRoomRequest] = ...,
        retrieveAuditLogRequest : typing.Optional[global___RetrieveAuditLogRequest] = ...,
        retrieveDataRoomStatusRequest : typing.Optional[global___RetrieveDataRoomStatusRequest] = ...,
        updateDataRoomStatusRequest : typing.Optional[global___UpdateDataRoomStatusRequest] = ...,
        retrievePublishedDatasetsRequest : typing.Optional[global___RetrievePublishedDatasetsRequest] = ...,
        removePublishedDatasetRequest : typing.Optional[global___RemovePublishedDatasetRequest] = ...,
        jobStatusRequest : typing.Optional[global___JobStatusRequest] = ...,
        getResultsRequest : typing.Optional[global___GetResultsRequest] = ...,
        createConfigurationCommitRequest : typing.Optional[global___CreateConfigurationCommitRequest] = ...,
        executeDevelopmentComputeRequest : typing.Optional[global___ExecuteDevelopmentComputeRequest] = ...,
        generateMergeApprovalSignatureRequest : typing.Optional[global___GenerateMergeApprovalSignatureRequest] = ...,
        mergeConfigurationCommitRequest : typing.Optional[global___MergeConfigurationCommitRequest] = ...,
        retrieveDataRoomConfigurationHistoryRequest : typing.Optional[global___RetrieveDataRoomConfigurationHistoryRequest] = ...,
        retrieveConfigurationCommitApproversRequest : typing.Optional[global___RetrieveConfigurationCommitApproversRequest] = ...,
        retrieveConfigurationCommitRequest : typing.Optional[global___RetrieveConfigurationCommitRequest] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"createConfigurationCommitRequest",b"createConfigurationCommitRequest",u"createDataRoomRequest",b"createDataRoomRequest",u"executeComputeRequest",b"executeComputeRequest",u"executeDevelopmentComputeRequest",b"executeDevelopmentComputeRequest",u"gcg_request",b"gcg_request",u"generateMergeApprovalSignatureRequest",b"generateMergeApprovalSignatureRequest",u"getResultsRequest",b"getResultsRequest",u"jobStatusRequest",b"jobStatusRequest",u"mergeConfigurationCommitRequest",b"mergeConfigurationCommitRequest",u"publishDatasetToDataRoomRequest",b"publishDatasetToDataRoomRequest",u"removePublishedDatasetRequest",b"removePublishedDatasetRequest",u"retrieveAuditLogRequest",b"retrieveAuditLogRequest",u"retrieveConfigurationCommitApproversRequest",b"retrieveConfigurationCommitApproversRequest",u"retrieveConfigurationCommitRequest",b"retrieveConfigurationCommitRequest",u"retrieveDataRoomConfigurationHistoryRequest",b"retrieveDataRoomConfigurationHistoryRequest",u"retrieveDataRoomRequest",b"retrieveDataRoomRequest",u"retrieveDataRoomStatusRequest",b"retrieveDataRoomStatusRequest",u"retrievePublishedDatasetsRequest",b"retrievePublishedDatasetsRequest",u"updateDataRoomStatusRequest",b"updateDataRoomStatusRequest"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"createConfigurationCommitRequest",b"createConfigurationCommitRequest",u"createDataRoomRequest",b"createDataRoomRequest",u"executeComputeRequest",b"executeComputeRequest",u"executeDevelopmentComputeRequest",b"executeDevelopmentComputeRequest",u"gcg_request",b"gcg_request",u"generateMergeApprovalSignatureRequest",b"generateMergeApprovalSignatureRequest",u"getResultsRequest",b"getResultsRequest",u"jobStatusRequest",b"jobStatusRequest",u"mergeConfigurationCommitRequest",b"mergeConfigurationCommitRequest",u"publishDatasetToDataRoomRequest",b"publishDatasetToDataRoomRequest",u"removePublishedDatasetRequest",b"removePublishedDatasetRequest",u"retrieveAuditLogRequest",b"retrieveAuditLogRequest",u"retrieveConfigurationCommitApproversRequest",b"retrieveConfigurationCommitApproversRequest",u"retrieveConfigurationCommitRequest",b"retrieveConfigurationCommitRequest",u"retrieveDataRoomConfigurationHistoryRequest",b"retrieveDataRoomConfigurationHistoryRequest",u"retrieveDataRoomRequest",b"retrieveDataRoomRequest",u"retrieveDataRoomStatusRequest",b"retrieveDataRoomStatusRequest",u"retrievePublishedDatasetsRequest",b"retrievePublishedDatasetsRequest",u"updateDataRoomStatusRequest",b"updateDataRoomStatusRequest"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal[u"gcg_request",b"gcg_request"]) -> typing.Optional[typing_extensions.Literal["executeComputeRequest","createDataRoomRequest","publishDatasetToDataRoomRequest","retrieveDataRoomRequest","retrieveAuditLogRequest","retrieveDataRoomStatusRequest","updateDataRoomStatusRequest","retrievePublishedDatasetsRequest","removePublishedDatasetRequest","jobStatusRequest","getResultsRequest","createConfigurationCommitRequest","executeDevelopmentComputeRequest","generateMergeApprovalSignatureRequest","mergeConfigurationCommitRequest","retrieveDataRoomConfigurationHistoryRequest","retrieveConfigurationCommitApproversRequest","retrieveConfigurationCommitRequest"]]: ...
global___GcgRequest = GcgRequest

class GcgResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    FAILURE_FIELD_NUMBER: builtins.int
    EXECUTECOMPUTERESPONSE_FIELD_NUMBER: builtins.int
    CREATEDATAROOMRESPONSE_FIELD_NUMBER: builtins.int
    PUBLISHDATASETTODATAROOMRESPONSE_FIELD_NUMBER: builtins.int
    RETRIEVEDATAROOMRESPONSE_FIELD_NUMBER: builtins.int
    RETRIEVEAUDITLOGRESPONSE_FIELD_NUMBER: builtins.int
    RETRIEVEDATAROOMSTATUSRESPONSE_FIELD_NUMBER: builtins.int
    UPDATEDATAROOMSTATUSRESPONSE_FIELD_NUMBER: builtins.int
    RETRIEVEPUBLISHEDDATASETSRESPONSE_FIELD_NUMBER: builtins.int
    REMOVEPUBLISHEDDATASETRESPONSE_FIELD_NUMBER: builtins.int
    JOBSTATUSRESPONSE_FIELD_NUMBER: builtins.int
    GETRESULTSRESPONSECHUNK_FIELD_NUMBER: builtins.int
    GETRESULTSRESPONSEFOOTER_FIELD_NUMBER: builtins.int
    CREATECONFIGURATIONCOMMITRESPONSE_FIELD_NUMBER: builtins.int
    GENERATEMERGEAPPROVALSIGNATURERESPONSE_FIELD_NUMBER: builtins.int
    MERGECONFIGURATIONCOMMITRESPONSE_FIELD_NUMBER: builtins.int
    RETRIEVEDATAROOMCONFIGURATIONHISTORYRESPONSE_FIELD_NUMBER: builtins.int
    RETRIEVECONFIGURATIONCOMMITAPPROVERSRESPONSE_FIELD_NUMBER: builtins.int
    RETRIEVECONFIGURATIONCOMMITRESPONSE_FIELD_NUMBER: builtins.int
    failure: typing.Text = ...
    @property
    def executeComputeResponse(self) -> global___ExecuteComputeResponse: ...
    @property
    def createDataRoomResponse(self) -> global___CreateDataRoomResponse: ...
    @property
    def publishDatasetToDataRoomResponse(self) -> global___PublishDatasetToDataRoomResponse: ...
    @property
    def retrieveDataRoomResponse(self) -> global___RetrieveDataRoomResponse: ...
    @property
    def retrieveAuditLogResponse(self) -> global___RetrieveAuditLogResponse: ...
    @property
    def retrieveDataRoomStatusResponse(self) -> global___RetrieveDataRoomStatusResponse: ...
    @property
    def updateDataRoomStatusResponse(self) -> global___UpdateDataRoomStatusResponse: ...
    @property
    def retrievePublishedDatasetsResponse(self) -> global___RetrievePublishedDatasetsResponse: ...
    @property
    def removePublishedDatasetResponse(self) -> global___RemovePublishedDatasetResponse: ...
    @property
    def jobStatusResponse(self) -> global___JobStatusResponse: ...
    @property
    def getResultsResponseChunk(self) -> global___GetResultsResponseChunk: ...
    @property
    def getResultsResponseFooter(self) -> global___GetResultsResponseFooter: ...
    @property
    def createConfigurationCommitResponse(self) -> global___CreateConfigurationCommitResponse: ...
    @property
    def generateMergeApprovalSignatureResponse(self) -> global___GenerateMergeApprovalSignatureResponse: ...
    @property
    def mergeConfigurationCommitResponse(self) -> global___MergeConfigurationCommitResponse: ...
    @property
    def retrieveDataRoomConfigurationHistoryResponse(self) -> global___RetrieveDataRoomConfigurationHistoryResponse: ...
    @property
    def retrieveConfigurationCommitApproversResponse(self) -> global___RetrieveConfigurationCommitApproversResponse: ...
    @property
    def retrieveConfigurationCommitResponse(self) -> global___RetrieveConfigurationCommitResponse: ...
    def __init__(self,
        *,
        failure : typing.Text = ...,
        executeComputeResponse : typing.Optional[global___ExecuteComputeResponse] = ...,
        createDataRoomResponse : typing.Optional[global___CreateDataRoomResponse] = ...,
        publishDatasetToDataRoomResponse : typing.Optional[global___PublishDatasetToDataRoomResponse] = ...,
        retrieveDataRoomResponse : typing.Optional[global___RetrieveDataRoomResponse] = ...,
        retrieveAuditLogResponse : typing.Optional[global___RetrieveAuditLogResponse] = ...,
        retrieveDataRoomStatusResponse : typing.Optional[global___RetrieveDataRoomStatusResponse] = ...,
        updateDataRoomStatusResponse : typing.Optional[global___UpdateDataRoomStatusResponse] = ...,
        retrievePublishedDatasetsResponse : typing.Optional[global___RetrievePublishedDatasetsResponse] = ...,
        removePublishedDatasetResponse : typing.Optional[global___RemovePublishedDatasetResponse] = ...,
        jobStatusResponse : typing.Optional[global___JobStatusResponse] = ...,
        getResultsResponseChunk : typing.Optional[global___GetResultsResponseChunk] = ...,
        getResultsResponseFooter : typing.Optional[global___GetResultsResponseFooter] = ...,
        createConfigurationCommitResponse : typing.Optional[global___CreateConfigurationCommitResponse] = ...,
        generateMergeApprovalSignatureResponse : typing.Optional[global___GenerateMergeApprovalSignatureResponse] = ...,
        mergeConfigurationCommitResponse : typing.Optional[global___MergeConfigurationCommitResponse] = ...,
        retrieveDataRoomConfigurationHistoryResponse : typing.Optional[global___RetrieveDataRoomConfigurationHistoryResponse] = ...,
        retrieveConfigurationCommitApproversResponse : typing.Optional[global___RetrieveConfigurationCommitApproversResponse] = ...,
        retrieveConfigurationCommitResponse : typing.Optional[global___RetrieveConfigurationCommitResponse] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"createConfigurationCommitResponse",b"createConfigurationCommitResponse",u"createDataRoomResponse",b"createDataRoomResponse",u"executeComputeResponse",b"executeComputeResponse",u"failure",b"failure",u"gcg_response",b"gcg_response",u"generateMergeApprovalSignatureResponse",b"generateMergeApprovalSignatureResponse",u"getResultsResponseChunk",b"getResultsResponseChunk",u"getResultsResponseFooter",b"getResultsResponseFooter",u"jobStatusResponse",b"jobStatusResponse",u"mergeConfigurationCommitResponse",b"mergeConfigurationCommitResponse",u"publishDatasetToDataRoomResponse",b"publishDatasetToDataRoomResponse",u"removePublishedDatasetResponse",b"removePublishedDatasetResponse",u"retrieveAuditLogResponse",b"retrieveAuditLogResponse",u"retrieveConfigurationCommitApproversResponse",b"retrieveConfigurationCommitApproversResponse",u"retrieveConfigurationCommitResponse",b"retrieveConfigurationCommitResponse",u"retrieveDataRoomConfigurationHistoryResponse",b"retrieveDataRoomConfigurationHistoryResponse",u"retrieveDataRoomResponse",b"retrieveDataRoomResponse",u"retrieveDataRoomStatusResponse",b"retrieveDataRoomStatusResponse",u"retrievePublishedDatasetsResponse",b"retrievePublishedDatasetsResponse",u"updateDataRoomStatusResponse",b"updateDataRoomStatusResponse"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"createConfigurationCommitResponse",b"createConfigurationCommitResponse",u"createDataRoomResponse",b"createDataRoomResponse",u"executeComputeResponse",b"executeComputeResponse",u"failure",b"failure",u"gcg_response",b"gcg_response",u"generateMergeApprovalSignatureResponse",b"generateMergeApprovalSignatureResponse",u"getResultsResponseChunk",b"getResultsResponseChunk",u"getResultsResponseFooter",b"getResultsResponseFooter",u"jobStatusResponse",b"jobStatusResponse",u"mergeConfigurationCommitResponse",b"mergeConfigurationCommitResponse",u"publishDatasetToDataRoomResponse",b"publishDatasetToDataRoomResponse",u"removePublishedDatasetResponse",b"removePublishedDatasetResponse",u"retrieveAuditLogResponse",b"retrieveAuditLogResponse",u"retrieveConfigurationCommitApproversResponse",b"retrieveConfigurationCommitApproversResponse",u"retrieveConfigurationCommitResponse",b"retrieveConfigurationCommitResponse",u"retrieveDataRoomConfigurationHistoryResponse",b"retrieveDataRoomConfigurationHistoryResponse",u"retrieveDataRoomResponse",b"retrieveDataRoomResponse",u"retrieveDataRoomStatusResponse",b"retrieveDataRoomStatusResponse",u"retrievePublishedDatasetsResponse",b"retrievePublishedDatasetsResponse",u"updateDataRoomStatusResponse",b"updateDataRoomStatusResponse"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal[u"gcg_response",b"gcg_response"]) -> typing.Optional[typing_extensions.Literal["failure","executeComputeResponse","createDataRoomResponse","publishDatasetToDataRoomResponse","retrieveDataRoomResponse","retrieveAuditLogResponse","retrieveDataRoomStatusResponse","updateDataRoomStatusResponse","retrievePublishedDatasetsResponse","removePublishedDatasetResponse","jobStatusResponse","getResultsResponseChunk","getResultsResponseFooter","createConfigurationCommitResponse","generateMergeApprovalSignatureResponse","mergeConfigurationCommitResponse","retrieveDataRoomConfigurationHistoryResponse","retrieveConfigurationCommitApproversResponse","retrieveConfigurationCommitResponse"]]: ...
global___GcgResponse = GcgResponse

class CreateDataRoomRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    DATAROOM_FIELD_NUMBER: builtins.int
    INITIALCONFIGURATION_FIELD_NUMBER: builtins.int
    @property
    def dataRoom(self) -> data_room_pb2.DataRoom: ...
    @property
    def initialConfiguration(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[data_room_pb2.ConfigurationModification]: ...
    def __init__(self,
        *,
        dataRoom : typing.Optional[data_room_pb2.DataRoom] = ...,
        initialConfiguration : typing.Optional[typing.Iterable[data_room_pb2.ConfigurationModification]] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"dataRoom",b"dataRoom"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"dataRoom",b"dataRoom",u"initialConfiguration",b"initialConfiguration"]) -> None: ...
global___CreateDataRoomRequest = CreateDataRoomRequest

class CreateDataRoomResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    DATAROOMID_FIELD_NUMBER: builtins.int
    DATAROOMVALIDATIONERROR_FIELD_NUMBER: builtins.int
    dataRoomId: builtins.bytes = ...
    @property
    def dataRoomValidationError(self) -> global___DataRoomValidationError: ...
    def __init__(self,
        *,
        dataRoomId : builtins.bytes = ...,
        dataRoomValidationError : typing.Optional[global___DataRoomValidationError] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"create_data_room_response",b"create_data_room_response",u"dataRoomId",b"dataRoomId",u"dataRoomValidationError",b"dataRoomValidationError"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"create_data_room_response",b"create_data_room_response",u"dataRoomId",b"dataRoomId",u"dataRoomValidationError",b"dataRoomValidationError"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal[u"create_data_room_response",b"create_data_room_response"]) -> typing.Optional[typing_extensions.Literal["dataRoomId","dataRoomValidationError"]]: ...
global___CreateDataRoomResponse = CreateDataRoomResponse

class DataRoomValidationError(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    MESSAGE_FIELD_NUMBER: builtins.int
    PERMISSIONINDEX_FIELD_NUMBER: builtins.int
    COMPUTENODEID_FIELD_NUMBER: builtins.int
    USERPERMISSIONID_FIELD_NUMBER: builtins.int
    ATTESTATIONSPECIFICATIONID_FIELD_NUMBER: builtins.int
    AUTHENTICATIONMETHODID_FIELD_NUMBER: builtins.int
    message: typing.Text = ...
    permissionIndex: builtins.int = ...
    computeNodeId: typing.Text = ...
    userPermissionId: typing.Text = ...
    attestationSpecificationId: typing.Text = ...
    authenticationMethodId: typing.Text = ...
    def __init__(self,
        *,
        message : typing.Text = ...,
        permissionIndex : builtins.int = ...,
        computeNodeId : typing.Text = ...,
        userPermissionId : typing.Text = ...,
        attestationSpecificationId : typing.Text = ...,
        authenticationMethodId : typing.Text = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"_attestationSpecificationId",b"_attestationSpecificationId",u"_authenticationMethodId",b"_authenticationMethodId",u"_computeNodeId",b"_computeNodeId",u"_permissionIndex",b"_permissionIndex",u"_userPermissionId",b"_userPermissionId",u"attestationSpecificationId",b"attestationSpecificationId",u"authenticationMethodId",b"authenticationMethodId",u"computeNodeId",b"computeNodeId",u"permissionIndex",b"permissionIndex",u"userPermissionId",b"userPermissionId"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"_attestationSpecificationId",b"_attestationSpecificationId",u"_authenticationMethodId",b"_authenticationMethodId",u"_computeNodeId",b"_computeNodeId",u"_permissionIndex",b"_permissionIndex",u"_userPermissionId",b"_userPermissionId",u"attestationSpecificationId",b"attestationSpecificationId",u"authenticationMethodId",b"authenticationMethodId",u"computeNodeId",b"computeNodeId",u"message",b"message",u"permissionIndex",b"permissionIndex",u"userPermissionId",b"userPermissionId"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal[u"_attestationSpecificationId",b"_attestationSpecificationId"]) -> typing.Optional[typing_extensions.Literal["attestationSpecificationId"]]: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal[u"_authenticationMethodId",b"_authenticationMethodId"]) -> typing.Optional[typing_extensions.Literal["authenticationMethodId"]]: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal[u"_computeNodeId",b"_computeNodeId"]) -> typing.Optional[typing_extensions.Literal["computeNodeId"]]: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal[u"_permissionIndex",b"_permissionIndex"]) -> typing.Optional[typing_extensions.Literal["permissionIndex"]]: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal[u"_userPermissionId",b"_userPermissionId"]) -> typing.Optional[typing_extensions.Literal["userPermissionId"]]: ...
global___DataRoomValidationError = DataRoomValidationError

class PublishDatasetToDataRoomRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    DATASETHASH_FIELD_NUMBER: builtins.int
    DATAROOMID_FIELD_NUMBER: builtins.int
    LEAFNAME_FIELD_NUMBER: builtins.int
    ENCRYPTIONKEY_FIELD_NUMBER: builtins.int
    SCOPE_FIELD_NUMBER: builtins.int
    datasetHash: builtins.bytes = ...
    dataRoomId: builtins.bytes = ...
    leafName: typing.Text = ...
    encryptionKey: builtins.bytes = ...
    scope: builtins.bytes = ...
    def __init__(self,
        *,
        datasetHash : builtins.bytes = ...,
        dataRoomId : builtins.bytes = ...,
        leafName : typing.Text = ...,
        encryptionKey : builtins.bytes = ...,
        scope : builtins.bytes = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"dataRoomId",b"dataRoomId",u"datasetHash",b"datasetHash",u"encryptionKey",b"encryptionKey",u"leafName",b"leafName",u"scope",b"scope"]) -> None: ...
global___PublishDatasetToDataRoomRequest = PublishDatasetToDataRoomRequest

class PublishDatasetToDataRoomResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    def __init__(self,
        ) -> None: ...
global___PublishDatasetToDataRoomResponse = PublishDatasetToDataRoomResponse

class ExecuteComputeRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    DATAROOMID_FIELD_NUMBER: builtins.int
    COMPUTENODENAMES_FIELD_NUMBER: builtins.int
    ISDRYRUN_FIELD_NUMBER: builtins.int
    SCOPE_FIELD_NUMBER: builtins.int
    dataRoomId: builtins.bytes = ...
    @property
    def computeNodeNames(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[typing.Text]: ...
    isDryRun: builtins.bool = ...
    scope: builtins.bytes = ...
    def __init__(self,
        *,
        dataRoomId : builtins.bytes = ...,
        computeNodeNames : typing.Optional[typing.Iterable[typing.Text]] = ...,
        isDryRun : builtins.bool = ...,
        scope : builtins.bytes = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"computeNodeNames",b"computeNodeNames",u"dataRoomId",b"dataRoomId",u"isDryRun",b"isDryRun",u"scope",b"scope"]) -> None: ...
global___ExecuteComputeRequest = ExecuteComputeRequest

class ExecuteDevelopmentComputeRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CONFIGURATIONCOMMITID_FIELD_NUMBER: builtins.int
    COMPUTENODENAMES_FIELD_NUMBER: builtins.int
    ISDRYRUN_FIELD_NUMBER: builtins.int
    SCOPE_FIELD_NUMBER: builtins.int
    configurationCommitId: builtins.bytes = ...
    @property
    def computeNodeNames(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[typing.Text]: ...
    isDryRun: builtins.bool = ...
    scope: builtins.bytes = ...
    def __init__(self,
        *,
        configurationCommitId : builtins.bytes = ...,
        computeNodeNames : typing.Optional[typing.Iterable[typing.Text]] = ...,
        isDryRun : builtins.bool = ...,
        scope : builtins.bytes = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"computeNodeNames",b"computeNodeNames",u"configurationCommitId",b"configurationCommitId",u"isDryRun",b"isDryRun",u"scope",b"scope"]) -> None: ...
global___ExecuteDevelopmentComputeRequest = ExecuteDevelopmentComputeRequest

class ExecuteComputeResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    JOBID_FIELD_NUMBER: builtins.int
    jobId: builtins.bytes = ...
    def __init__(self,
        *,
        jobId : builtins.bytes = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"jobId",b"jobId"]) -> None: ...
global___ExecuteComputeResponse = ExecuteComputeResponse

class JobStatusRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    JOBID_FIELD_NUMBER: builtins.int
    jobId: builtins.bytes = ...
    def __init__(self,
        *,
        jobId : builtins.bytes = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"jobId",b"jobId"]) -> None: ...
global___JobStatusRequest = JobStatusRequest

class JobStatusResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    COMPLETECOMPUTENODENAMES_FIELD_NUMBER: builtins.int
    @property
    def completeComputeNodeNames(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[typing.Text]: ...
    def __init__(self,
        *,
        completeComputeNodeNames : typing.Optional[typing.Iterable[typing.Text]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"completeComputeNodeNames",b"completeComputeNodeNames"]) -> None: ...
global___JobStatusResponse = JobStatusResponse

class GetResultsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    JOBID_FIELD_NUMBER: builtins.int
    COMPUTENODENAME_FIELD_NUMBER: builtins.int
    jobId: builtins.bytes = ...
    computeNodeName: typing.Text = ...
    def __init__(self,
        *,
        jobId : builtins.bytes = ...,
        computeNodeName : typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"computeNodeName",b"computeNodeName",u"jobId",b"jobId"]) -> None: ...
global___GetResultsRequest = GetResultsRequest

class GetResultsResponseChunk(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    DATA_FIELD_NUMBER: builtins.int
    data: builtins.bytes = ...
    def __init__(self,
        *,
        data : builtins.bytes = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"data",b"data"]) -> None: ...
global___GetResultsResponseChunk = GetResultsResponseChunk

class GetResultsResponseFooter(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    def __init__(self,
        ) -> None: ...
global___GetResultsResponseFooter = GetResultsResponseFooter

class RetrieveDataRoomRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    DATAROOMID_FIELD_NUMBER: builtins.int
    dataRoomId: builtins.bytes = ...
    def __init__(self,
        *,
        dataRoomId : builtins.bytes = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"dataRoomId",b"dataRoomId"]) -> None: ...
global___RetrieveDataRoomRequest = RetrieveDataRoomRequest

class RetrieveDataRoomResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    DATAROOM_FIELD_NUMBER: builtins.int
    @property
    def dataRoom(self) -> data_room_pb2.DataRoom: ...
    def __init__(self,
        *,
        dataRoom : typing.Optional[data_room_pb2.DataRoom] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"dataRoom",b"dataRoom"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"dataRoom",b"dataRoom"]) -> None: ...
global___RetrieveDataRoomResponse = RetrieveDataRoomResponse

class RetrieveAuditLogRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    DATAROOMID_FIELD_NUMBER: builtins.int
    SCOPE_FIELD_NUMBER: builtins.int
    dataRoomId: builtins.bytes = ...
    scope: builtins.bytes = ...
    def __init__(self,
        *,
        dataRoomId : builtins.bytes = ...,
        scope : builtins.bytes = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"dataRoomId",b"dataRoomId",u"scope",b"scope"]) -> None: ...
global___RetrieveAuditLogRequest = RetrieveAuditLogRequest

class RetrieveAuditLogResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    LOG_FIELD_NUMBER: builtins.int
    log: builtins.bytes = ...
    def __init__(self,
        *,
        log : builtins.bytes = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"log",b"log"]) -> None: ...
global___RetrieveAuditLogResponse = RetrieveAuditLogResponse

class RetrieveDataRoomStatusRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    DATAROOMID_FIELD_NUMBER: builtins.int
    SCOPE_FIELD_NUMBER: builtins.int
    dataRoomId: builtins.bytes = ...
    scope: builtins.bytes = ...
    def __init__(self,
        *,
        dataRoomId : builtins.bytes = ...,
        scope : builtins.bytes = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"dataRoomId",b"dataRoomId",u"scope",b"scope"]) -> None: ...
global___RetrieveDataRoomStatusRequest = RetrieveDataRoomStatusRequest

class RetrieveDataRoomStatusResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    STATUS_FIELD_NUMBER: builtins.int
    status: global___DataRoomStatus.V = ...
    def __init__(self,
        *,
        status : global___DataRoomStatus.V = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"status",b"status"]) -> None: ...
global___RetrieveDataRoomStatusResponse = RetrieveDataRoomStatusResponse

class UpdateDataRoomStatusRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    DATAROOMID_FIELD_NUMBER: builtins.int
    SCOPE_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    dataRoomId: builtins.bytes = ...
    scope: builtins.bytes = ...
    status: global___DataRoomStatus.V = ...
    def __init__(self,
        *,
        dataRoomId : builtins.bytes = ...,
        scope : builtins.bytes = ...,
        status : global___DataRoomStatus.V = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"dataRoomId",b"dataRoomId",u"scope",b"scope",u"status",b"status"]) -> None: ...
global___UpdateDataRoomStatusRequest = UpdateDataRoomStatusRequest

class UpdateDataRoomStatusResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    def __init__(self,
        ) -> None: ...
global___UpdateDataRoomStatusResponse = UpdateDataRoomStatusResponse

class RetrievePublishedDatasetsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    DATAROOMID_FIELD_NUMBER: builtins.int
    SCOPE_FIELD_NUMBER: builtins.int
    dataRoomId: builtins.bytes = ...
    scope: builtins.bytes = ...
    def __init__(self,
        *,
        dataRoomId : builtins.bytes = ...,
        scope : builtins.bytes = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"dataRoomId",b"dataRoomId",u"scope",b"scope"]) -> None: ...
global___RetrievePublishedDatasetsRequest = RetrievePublishedDatasetsRequest

class PublishedDataset(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    LEAFNAME_FIELD_NUMBER: builtins.int
    USER_FIELD_NUMBER: builtins.int
    TIMESTAMP_FIELD_NUMBER: builtins.int
    DATASETHASH_FIELD_NUMBER: builtins.int
    leafName: typing.Text = ...
    user: typing.Text = ...
    timestamp: builtins.int = ...
    datasetHash: builtins.bytes = ...
    def __init__(self,
        *,
        leafName : typing.Text = ...,
        user : typing.Text = ...,
        timestamp : builtins.int = ...,
        datasetHash : builtins.bytes = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"datasetHash",b"datasetHash",u"leafName",b"leafName",u"timestamp",b"timestamp",u"user",b"user"]) -> None: ...
global___PublishedDataset = PublishedDataset

class RetrievePublishedDatasetsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PUBLISHEDDATASETS_FIELD_NUMBER: builtins.int
    @property
    def publishedDatasets(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PublishedDataset]: ...
    def __init__(self,
        *,
        publishedDatasets : typing.Optional[typing.Iterable[global___PublishedDataset]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"publishedDatasets",b"publishedDatasets"]) -> None: ...
global___RetrievePublishedDatasetsResponse = RetrievePublishedDatasetsResponse

class RemovePublishedDatasetRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    DATAROOMID_FIELD_NUMBER: builtins.int
    LEAFNAME_FIELD_NUMBER: builtins.int
    SCOPE_FIELD_NUMBER: builtins.int
    dataRoomId: builtins.bytes = ...
    leafName: typing.Text = ...
    scope: builtins.bytes = ...
    def __init__(self,
        *,
        dataRoomId : builtins.bytes = ...,
        leafName : typing.Text = ...,
        scope : builtins.bytes = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"dataRoomId",b"dataRoomId",u"leafName",b"leafName",u"scope",b"scope"]) -> None: ...
global___RemovePublishedDatasetRequest = RemovePublishedDatasetRequest

class RemovePublishedDatasetResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    def __init__(self,
        ) -> None: ...
global___RemovePublishedDatasetResponse = RemovePublishedDatasetResponse

class CreateConfigurationCommitRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    COMMIT_FIELD_NUMBER: builtins.int
    SCOPE_FIELD_NUMBER: builtins.int
    @property
    def commit(self) -> data_room_pb2.ConfigurationCommit: ...
    scope: builtins.bytes = ...
    def __init__(self,
        *,
        commit : typing.Optional[data_room_pb2.ConfigurationCommit] = ...,
        scope : builtins.bytes = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"commit",b"commit"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"commit",b"commit",u"scope",b"scope"]) -> None: ...
global___CreateConfigurationCommitRequest = CreateConfigurationCommitRequest

class CreateConfigurationCommitResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    COMMITID_FIELD_NUMBER: builtins.int
    commitId: builtins.bytes = ...
    def __init__(self,
        *,
        commitId : builtins.bytes = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"commitId",b"commitId"]) -> None: ...
global___CreateConfigurationCommitResponse = CreateConfigurationCommitResponse

class GenerateMergeApprovalSignatureRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    COMMITID_FIELD_NUMBER: builtins.int
    SCOPE_FIELD_NUMBER: builtins.int
    commitId: builtins.bytes = ...
    scope: builtins.bytes = ...
    def __init__(self,
        *,
        commitId : builtins.bytes = ...,
        scope : builtins.bytes = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"commitId",b"commitId",u"scope",b"scope"]) -> None: ...
global___GenerateMergeApprovalSignatureRequest = GenerateMergeApprovalSignatureRequest

class GenerateMergeApprovalSignatureResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    SIGNATURE_FIELD_NUMBER: builtins.int
    signature: builtins.bytes = ...
    def __init__(self,
        *,
        signature : builtins.bytes = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"signature",b"signature"]) -> None: ...
global___GenerateMergeApprovalSignatureResponse = GenerateMergeApprovalSignatureResponse

class MergeConfigurationCommitRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class ApprovalSignaturesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: typing.Text = ...
        value: builtins.bytes = ...
        def __init__(self,
            *,
            key : typing.Text = ...,
            value : builtins.bytes = ...,
            ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal[u"key",b"key",u"value",b"value"]) -> None: ...

    COMMITID_FIELD_NUMBER: builtins.int
    APPROVALSIGNATURES_FIELD_NUMBER: builtins.int
    SCOPE_FIELD_NUMBER: builtins.int
    commitId: builtins.bytes = ...
    @property
    def approvalSignatures(self) -> google.protobuf.internal.containers.ScalarMap[typing.Text, builtins.bytes]: ...
    scope: builtins.bytes = ...
    def __init__(self,
        *,
        commitId : builtins.bytes = ...,
        approvalSignatures : typing.Optional[typing.Mapping[typing.Text, builtins.bytes]] = ...,
        scope : builtins.bytes = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"approvalSignatures",b"approvalSignatures",u"commitId",b"commitId",u"scope",b"scope"]) -> None: ...
global___MergeConfigurationCommitRequest = MergeConfigurationCommitRequest

class RetrieveDataRoomConfigurationHistoryRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    DATAROOMID_FIELD_NUMBER: builtins.int
    dataRoomId: builtins.bytes = ...
    def __init__(self,
        *,
        dataRoomId : builtins.bytes = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"dataRoomId",b"dataRoomId"]) -> None: ...
global___RetrieveDataRoomConfigurationHistoryRequest = RetrieveDataRoomConfigurationHistoryRequest

class RetrieveDataRoomConfigurationHistoryResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CURRENTCONFIGURATION_FIELD_NUMBER: builtins.int
    CONFIGURATIONSHISTORY_FIELD_NUMBER: builtins.int
    PIN_FIELD_NUMBER: builtins.int
    @property
    def currentConfiguration(self) -> data_room_pb2.DataRoomConfiguration: ...
    @property
    def configurationsHistory(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.bytes]: ...
    pin: builtins.bytes = ...
    def __init__(self,
        *,
        currentConfiguration : typing.Optional[data_room_pb2.DataRoomConfiguration] = ...,
        configurationsHistory : typing.Optional[typing.Iterable[builtins.bytes]] = ...,
        pin : builtins.bytes = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"currentConfiguration",b"currentConfiguration"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"configurationsHistory",b"configurationsHistory",u"currentConfiguration",b"currentConfiguration",u"pin",b"pin"]) -> None: ...
global___RetrieveDataRoomConfigurationHistoryResponse = RetrieveDataRoomConfigurationHistoryResponse

class RetrieveConfigurationCommitApproversRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    COMMITID_FIELD_NUMBER: builtins.int
    SCOPE_FIELD_NUMBER: builtins.int
    commitId: builtins.bytes = ...
    scope: builtins.bytes = ...
    def __init__(self,
        *,
        commitId : builtins.bytes = ...,
        scope : builtins.bytes = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"commitId",b"commitId",u"scope",b"scope"]) -> None: ...
global___RetrieveConfigurationCommitApproversRequest = RetrieveConfigurationCommitApproversRequest

class RetrieveConfigurationCommitApproversResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    APPROVERS_FIELD_NUMBER: builtins.int
    @property
    def approvers(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[typing.Text]: ...
    def __init__(self,
        *,
        approvers : typing.Optional[typing.Iterable[typing.Text]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"approvers",b"approvers"]) -> None: ...
global___RetrieveConfigurationCommitApproversResponse = RetrieveConfigurationCommitApproversResponse

class RetrieveConfigurationCommitRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    COMMITID_FIELD_NUMBER: builtins.int
    SCOPE_FIELD_NUMBER: builtins.int
    commitId: builtins.bytes = ...
    scope: builtins.bytes = ...
    def __init__(self,
        *,
        commitId : builtins.bytes = ...,
        scope : builtins.bytes = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"commitId",b"commitId",u"scope",b"scope"]) -> None: ...
global___RetrieveConfigurationCommitRequest = RetrieveConfigurationCommitRequest

class RetrieveConfigurationCommitResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    COMMIT_FIELD_NUMBER: builtins.int
    @property
    def commit(self) -> data_room_pb2.ConfigurationCommit: ...
    def __init__(self,
        *,
        commit : typing.Optional[data_room_pb2.ConfigurationCommit] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"commit",b"commit"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"commit",b"commit"]) -> None: ...
global___RetrieveConfigurationCommitResponse = RetrieveConfigurationCommitResponse

class MergeConfigurationCommitResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    def __init__(self,
        ) -> None: ...
global___MergeConfigurationCommitResponse = MergeConfigurationCommitResponse

class DriverTaskConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    NOOP_FIELD_NUMBER: builtins.int
    STATICCONTENT_FIELD_NUMBER: builtins.int
    @property
    def noop(self) -> global___NoopConfig: ...
    @property
    def staticContent(self) -> global___StaticContentConfig: ...
    def __init__(self,
        *,
        noop : typing.Optional[global___NoopConfig] = ...,
        staticContent : typing.Optional[global___StaticContentConfig] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"driver_task_config",b"driver_task_config",u"noop",b"noop",u"staticContent",b"staticContent"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"driver_task_config",b"driver_task_config",u"noop",b"noop",u"staticContent",b"staticContent"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal[u"driver_task_config",b"driver_task_config"]) -> typing.Optional[typing_extensions.Literal["noop","staticContent"]]: ...
global___DriverTaskConfig = DriverTaskConfig

class NoopConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    def __init__(self,
        ) -> None: ...
global___NoopConfig = NoopConfig

class StaticContentConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CONTENT_FIELD_NUMBER: builtins.int
    content: builtins.bytes = ...
    def __init__(self,
        *,
        content : builtins.bytes = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"content",b"content"]) -> None: ...
global___StaticContentConfig = StaticContentConfig



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcg.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import data_room_pb2 as data__room__pb2
from . import attestation_pb2 as attestation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\tgcg.proto\x12\x03gcg\x1a\x0f\x64\x61ta_room.proto\x1a\x11\x61ttestation.proto\"\x83\x0b\n\nGcgRequest\x12;\n\x15\x65xecuteComputeRequest\x18\x02 \x01(\x0b\x32\x1a.gcg.ExecuteComputeRequestH\x00\x12;\n\x15\x63reateDataRoomRequest\x18\x03 \x01(\x0b\x32\x1a.gcg.CreateDataRoomRequestH\x00\x12O\n\x1fpublishDatasetToDataRoomRequest\x18\x04 \x01(\x0b\x32$.gcg.PublishDatasetToDataRoomRequestH\x00\x12?\n\x17retrieveDataRoomRequest\x18\x05 \x01(\x0b\x32\x1c.gcg.RetrieveDataRoomRequestH\x00\x12?\n\x17retrieveAuditLogRequest\x18\x06 \x01(\x0b\x32\x1c.gcg.RetrieveAuditLogRequestH\x00\x12K\n\x1dretrieveDataRoomStatusRequest\x18\x07 \x01(\x0b\x32\".gcg.RetrieveDataRoomStatusRequestH\x00\x12G\n\x1bupdateDataRoomStatusRequest\x18\n \x01(\x0b\x32 .gcg.UpdateDataRoomStatusRequestH\x00\x12Q\n retrievePublishedDatasetsRequest\x18\x0b \x01(\x0b\x32%.gcg.RetrievePublishedDatasetsRequestH\x00\x12K\n\x1dremovePublishedDatasetRequest\x18\x0c \x01(\x0b\x32\".gcg.RemovePublishedDatasetRequestH\x00\x12\x31\n\x10jobStatusRequest\x18\r \x01(\x0b\x32\x15.gcg.JobStatusRequestH\x00\x12\x33\n\x11getResultsRequest\x18\x0e \x01(\x0b\x32\x16.gcg.GetResultsRequestH\x00\x12Q\n createConfigurationCommitRequest\x18\x0f \x01(\x0b\x32%.gcg.CreateConfigurationCommitRequestH\x00\x12Q\n executeDevelopmentComputeRequest\x18\x10 \x01(\x0b\x32%.gcg.ExecuteDevelopmentComputeRequestH\x00\x12[\n%generateMergeApprovalSignatureRequest\x18\x11 \x01(\x0b\x32*.gcg.GenerateMergeApprovalSignatureRequestH\x00\x12O\n\x1fmergeConfigurationCommitRequest\x18\x12 \x01(\x0b\x32$.gcg.MergeConfigurationCommitRequestH\x00\x12g\n+retrieveDataRoomConfigurationHistoryRequest\x18\x13 \x01(\x0b\x32\x30.gcg.RetrieveDataRoomConfigurationHistoryRequestH\x00\x12g\n+retrieveConfigurationCommitApproversRequest\x18\x14 \x01(\x0b\x32\x30.gcg.RetrieveConfigurationCommitApproversRequestH\x00\x12U\n\"retrieveConfigurationCommitRequest\x18\x15 \x01(\x0b\x32\'.gcg.RetrieveConfigurationCommitRequestH\x00\x42\r\n\x0bgcg_request\"\xb4\x0b\n\x0bGcgResponse\x12\x11\n\x07\x66\x61ilure\x18\x01 \x01(\tH\x00\x12=\n\x16\x65xecuteComputeResponse\x18\x02 \x01(\x0b\x32\x1b.gcg.ExecuteComputeResponseH\x00\x12=\n\x16\x63reateDataRoomResponse\x18\x03 \x01(\x0b\x32\x1b.gcg.CreateDataRoomResponseH\x00\x12Q\n publishDatasetToDataRoomResponse\x18\x04 \x01(\x0b\x32%.gcg.PublishDatasetToDataRoomResponseH\x00\x12\x41\n\x18retrieveDataRoomResponse\x18\x05 \x01(\x0b\x32\x1d.gcg.RetrieveDataRoomResponseH\x00\x12\x41\n\x18retrieveAuditLogResponse\x18\x06 \x01(\x0b\x32\x1d.gcg.RetrieveAuditLogResponseH\x00\x12M\n\x1eretrieveDataRoomStatusResponse\x18\x07 \x01(\x0b\x32#.gcg.RetrieveDataRoomStatusResponseH\x00\x12I\n\x1cupdateDataRoomStatusResponse\x18\n \x01(\x0b\x32!.gcg.UpdateDataRoomStatusResponseH\x00\x12S\n!retrievePublishedDatasetsResponse\x18\x0b \x01(\x0b\x32&.gcg.RetrievePublishedDatasetsResponseH\x00\x12M\n\x1eremovePublishedDatasetResponse\x18\x0c \x01(\x0b\x32#.gcg.RemovePublishedDatasetResponseH\x00\x12\x33\n\x11jobStatusResponse\x18\r \x01(\x0b\x32\x16.gcg.JobStatusResponseH\x00\x12?\n\x17getResultsResponseChunk\x18\x0e \x01(\x0b\x32\x1c.gcg.GetResultsResponseChunkH\x00\x12\x41\n\x18getResultsResponseFooter\x18\x0f \x01(\x0b\x32\x1d.gcg.GetResultsResponseFooterH\x00\x12S\n!createConfigurationCommitResponse\x18\x10 \x01(\x0b\x32&.gcg.CreateConfigurationCommitResponseH\x00\x12]\n&generateMergeApprovalSignatureResponse\x18\x11 \x01(\x0b\x32+.gcg.GenerateMergeApprovalSignatureResponseH\x00\x12Q\n mergeConfigurationCommitResponse\x18\x12 \x01(\x0b\x32%.gcg.MergeConfigurationCommitResponseH\x00\x12i\n,retrieveDataRoomConfigurationHistoryResponse\x18\x13 \x01(\x0b\x32\x31.gcg.RetrieveDataRoomConfigurationHistoryResponseH\x00\x12i\n,retrieveConfigurationCommitApproversResponse\x18\x14 \x01(\x0b\x32\x31.gcg.RetrieveConfigurationCommitApproversResponseH\x00\x12W\n#retrieveConfigurationCommitResponse\x18\x15 \x01(\x0b\x32(.gcg.RetrieveConfigurationCommitResponseH\x00\x42\x0e\n\x0cgcg_response\"\x88\x01\n\x15\x43reateDataRoomRequest\x12%\n\x08\x64\x61taRoom\x18\x01 \x01(\x0b\x32\x13.data_room.DataRoom\x12\x42\n\x14initialConfiguration\x18\x03 \x03(\x0b\x32$.data_room.ConfigurationModificationJ\x04\x08\x02\x10\x03\"\x8c\x01\n\x16\x43reateDataRoomResponse\x12\x14\n\ndataRoomId\x18\x01 \x01(\x0cH\x00\x12?\n\x17\x64\x61taRoomValidationError\x18\x02 \x01(\x0b\x32\x1c.gcg.DataRoomValidationErrorH\x00\x42\x1b\n\x19\x63reate_data_room_response\"\xd2\x02\n\x17\x44\x61taRoomValidationError\x12\x0f\n\x07message\x18\x01 \x01(\t\x12\x1c\n\x0fpermissionIndex\x18\x06 \x01(\x04H\x00\x88\x01\x01\x12\x1a\n\rcomputeNodeId\x18\t \x01(\tH\x01\x88\x01\x01\x12\x1d\n\x10userPermissionId\x18\n \x01(\tH\x02\x88\x01\x01\x12\'\n\x1a\x61ttestationSpecificationId\x18\x0b \x01(\tH\x03\x88\x01\x01\x12#\n\x16\x61uthenticationMethodId\x18\x0c \x01(\tH\x04\x88\x01\x01\x42\x12\n\x10_permissionIndexB\x10\n\x0e_computeNodeIdB\x13\n\x11_userPermissionIdB\x1d\n\x1b_attestationSpecificationIdB\x19\n\x17_authenticationMethodIdJ\x04\x08\x02\x10\x06J\x04\x08\x07\x10\t\"\x82\x01\n\x1fPublishDatasetToDataRoomRequest\x12\x13\n\x0b\x64\x61tasetHash\x18\x01 \x01(\x0c\x12\x12\n\ndataRoomId\x18\x02 \x01(\x0c\x12\x10\n\x08leafName\x18\x03 \x01(\t\x12\x15\n\rencryptionKey\x18\x04 \x01(\x0c\x12\r\n\x05scope\x18\x05 \x01(\x0c\"\"\n PublishDatasetToDataRoomResponse\"f\n\x15\x45xecuteComputeRequest\x12\x12\n\ndataRoomId\x18\x01 \x01(\x0c\x12\x18\n\x10\x63omputeNodeNames\x18\x02 \x03(\t\x12\x10\n\x08isDryRun\x18\x03 \x01(\x08\x12\r\n\x05scope\x18\x04 \x01(\x0c\"|\n ExecuteDevelopmentComputeRequest\x12\x1d\n\x15\x63onfigurationCommitId\x18\x01 \x01(\x0c\x12\x18\n\x10\x63omputeNodeNames\x18\x02 \x03(\t\x12\x10\n\x08isDryRun\x18\x03 \x01(\x08\x12\r\n\x05scope\x18\x04 \x01(\x0c\"\'\n\x16\x45xecuteComputeResponse\x12\r\n\x05jobId\x18\x01 \x01(\x0c\"!\n\x10JobStatusRequest\x12\r\n\x05jobId\x18\x01 \x01(\x0c\"5\n\x11JobStatusResponse\x12 \n\x18\x63ompleteComputeNodeNames\x18\x01 \x03(\t\";\n\x11GetResultsRequest\x12\r\n\x05jobId\x18\x01 \x01(\x0c\x12\x17\n\x0f\x63omputeNodeName\x18\x02 \x01(\t\"\'\n\x17GetResultsResponseChunk\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\"\x1a\n\x18GetResultsResponseFooter\"3\n\x17RetrieveDataRoomRequest\x12\x12\n\ndataRoomId\x18\x01 \x01(\x0cJ\x04\x08\x02\x10\x03\"A\n\x18RetrieveDataRoomResponse\x12%\n\x08\x64\x61taRoom\x18\x01 \x01(\x0b\x32\x13.data_room.DataRoom\"<\n\x17RetrieveAuditLogRequest\x12\x12\n\ndataRoomId\x18\x01 \x01(\x0c\x12\r\n\x05scope\x18\x02 \x01(\x0c\"\'\n\x18RetrieveAuditLogResponse\x12\x0b\n\x03log\x18\x01 \x01(\x0c\"B\n\x1dRetrieveDataRoomStatusRequest\x12\x12\n\ndataRoomId\x18\x01 \x01(\x0c\x12\r\n\x05scope\x18\x02 \x01(\x0c\"E\n\x1eRetrieveDataRoomStatusResponse\x12#\n\x06status\x18\x01 \x01(\x0e\x32\x13.gcg.DataRoomStatus\"e\n\x1bUpdateDataRoomStatusRequest\x12\x12\n\ndataRoomId\x18\x01 \x01(\x0c\x12\r\n\x05scope\x18\x02 \x01(\x0c\x12#\n\x06status\x18\x03 \x01(\x0e\x32\x13.gcg.DataRoomStatus\"\x1e\n\x1cUpdateDataRoomStatusResponse\"E\n RetrievePublishedDatasetsRequest\x12\x12\n\ndataRoomId\x18\x01 \x01(\x0c\x12\r\n\x05scope\x18\x02 \x01(\x0c\"Z\n\x10PublishedDataset\x12\x10\n\x08leafName\x18\x01 \x01(\t\x12\x0c\n\x04user\x18\x02 \x01(\t\x12\x11\n\ttimestamp\x18\x03 \x01(\x04\x12\x13\n\x0b\x64\x61tasetHash\x18\x04 \x01(\x0c\"U\n!RetrievePublishedDatasetsResponse\x12\x30\n\x11publishedDatasets\x18\x01 \x03(\x0b\x32\x15.gcg.PublishedDataset\"Z\n\x1dRemovePublishedDatasetRequest\x12\x12\n\ndataRoomId\x18\x02 \x01(\x0c\x12\x10\n\x08leafName\x18\x03 \x01(\t\x12\r\n\x05scope\x18\x04 \x01(\x0cJ\x04\x08\x01\x10\x02\" \n\x1eRemovePublishedDatasetResponse\"a\n CreateConfigurationCommitRequest\x12.\n\x06\x63ommit\x18\x01 \x01(\x0b\x32\x1e.data_room.ConfigurationCommit\x12\r\n\x05scope\x18\x02 \x01(\x0c\"5\n!CreateConfigurationCommitResponse\x12\x10\n\x08\x63ommitId\x18\x01 \x01(\x0c\"H\n%GenerateMergeApprovalSignatureRequest\x12\x10\n\x08\x63ommitId\x18\x01 \x01(\x0c\x12\r\n\x05scope\x18\x02 \x01(\x0c\";\n&GenerateMergeApprovalSignatureResponse\x12\x11\n\tsignature\x18\x01 \x01(\x0c\"\xd7\x01\n\x1fMergeConfigurationCommitRequest\x12\x10\n\x08\x63ommitId\x18\x01 \x01(\x0c\x12X\n\x12\x61pprovalSignatures\x18\x02 \x03(\x0b\x32<.gcg.MergeConfigurationCommitRequest.ApprovalSignaturesEntry\x12\r\n\x05scope\x18\x03 \x01(\x0c\x1a\x39\n\x17\x41pprovalSignaturesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"A\n+RetrieveDataRoomConfigurationHistoryRequest\x12\x12\n\ndataRoomId\x18\x01 \x01(\x0c\"\x9a\x01\n,RetrieveDataRoomConfigurationHistoryResponse\x12>\n\x14\x63urrentConfiguration\x18\x01 \x01(\x0b\x32 .data_room.DataRoomConfiguration\x12\x1d\n\x15\x63onfigurationsHistory\x18\x02 \x03(\x0c\x12\x0b\n\x03pin\x18\x03 \x01(\x0c\"N\n+RetrieveConfigurationCommitApproversRequest\x12\x10\n\x08\x63ommitId\x18\x01 \x01(\x0c\x12\r\n\x05scope\x18\x02 \x01(\x0c\"A\n,RetrieveConfigurationCommitApproversResponse\x12\x11\n\tapprovers\x18\x01 \x03(\t\"E\n\"RetrieveConfigurationCommitRequest\x12\x10\n\x08\x63ommitId\x18\x01 \x01(\x0c\x12\r\n\x05scope\x18\x02 \x01(\x0c\"U\n#RetrieveConfigurationCommitResponse\x12.\n\x06\x63ommit\x18\x01 \x01(\x0b\x32\x1e.data_room.ConfigurationCommit\"\"\n MergeConfigurationCommitResponse\"|\n\x10\x44riverTaskConfig\x12\x1f\n\x04noop\x18\x01 \x01(\x0b\x32\x0f.gcg.NoopConfigH\x00\x12\x31\n\rstaticContent\x18\x02 \x01(\x0b\x32\x18.gcg.StaticContentConfigH\x00\x42\x14\n\x12\x64river_task_config\"\x0c\n\nNoopConfig\"&\n\x13StaticContentConfig\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\x0c*)\n\x0e\x44\x61taRoomStatus\x12\n\n\x06\x41\x63tive\x10\x00\x12\x0b\n\x07Stopped\x10\x01\x62\x06proto3')

_DATAROOMSTATUS = DESCRIPTOR.enum_types_by_name['DataRoomStatus']
DataRoomStatus = enum_type_wrapper.EnumTypeWrapper(_DATAROOMSTATUS)
Active = 0
Stopped = 1


_GCGREQUEST = DESCRIPTOR.message_types_by_name['GcgRequest']
_GCGRESPONSE = DESCRIPTOR.message_types_by_name['GcgResponse']
_CREATEDATAROOMREQUEST = DESCRIPTOR.message_types_by_name['CreateDataRoomRequest']
_CREATEDATAROOMRESPONSE = DESCRIPTOR.message_types_by_name['CreateDataRoomResponse']
_DATAROOMVALIDATIONERROR = DESCRIPTOR.message_types_by_name['DataRoomValidationError']
_PUBLISHDATASETTODATAROOMREQUEST = DESCRIPTOR.message_types_by_name['PublishDatasetToDataRoomRequest']
_PUBLISHDATASETTODATAROOMRESPONSE = DESCRIPTOR.message_types_by_name['PublishDatasetToDataRoomResponse']
_EXECUTECOMPUTEREQUEST = DESCRIPTOR.message_types_by_name['ExecuteComputeRequest']
_EXECUTEDEVELOPMENTCOMPUTEREQUEST = DESCRIPTOR.message_types_by_name['ExecuteDevelopmentComputeRequest']
_EXECUTECOMPUTERESPONSE = DESCRIPTOR.message_types_by_name['ExecuteComputeResponse']
_JOBSTATUSREQUEST = DESCRIPTOR.message_types_by_name['JobStatusRequest']
_JOBSTATUSRESPONSE = DESCRIPTOR.message_types_by_name['JobStatusResponse']
_GETRESULTSREQUEST = DESCRIPTOR.message_types_by_name['GetResultsRequest']
_GETRESULTSRESPONSECHUNK = DESCRIPTOR.message_types_by_name['GetResultsResponseChunk']
_GETRESULTSRESPONSEFOOTER = DESCRIPTOR.message_types_by_name['GetResultsResponseFooter']
_RETRIEVEDATAROOMREQUEST = DESCRIPTOR.message_types_by_name['RetrieveDataRoomRequest']
_RETRIEVEDATAROOMRESPONSE = DESCRIPTOR.message_types_by_name['RetrieveDataRoomResponse']
_RETRIEVEAUDITLOGREQUEST = DESCRIPTOR.message_types_by_name['RetrieveAuditLogRequest']
_RETRIEVEAUDITLOGRESPONSE = DESCRIPTOR.message_types_by_name['RetrieveAuditLogResponse']
_RETRIEVEDATAROOMSTATUSREQUEST = DESCRIPTOR.message_types_by_name['RetrieveDataRoomStatusRequest']
_RETRIEVEDATAROOMSTATUSRESPONSE = DESCRIPTOR.message_types_by_name['RetrieveDataRoomStatusResponse']
_UPDATEDATAROOMSTATUSREQUEST = DESCRIPTOR.message_types_by_name['UpdateDataRoomStatusRequest']
_UPDATEDATAROOMSTATUSRESPONSE = DESCRIPTOR.message_types_by_name['UpdateDataRoomStatusResponse']
_RETRIEVEPUBLISHEDDATASETSREQUEST = DESCRIPTOR.message_types_by_name['RetrievePublishedDatasetsRequest']
_PUBLISHEDDATASET = DESCRIPTOR.message_types_by_name['PublishedDataset']
_RETRIEVEPUBLISHEDDATASETSRESPONSE = DESCRIPTOR.message_types_by_name['RetrievePublishedDatasetsResponse']
_REMOVEPUBLISHEDDATASETREQUEST = DESCRIPTOR.message_types_by_name['RemovePublishedDatasetRequest']
_REMOVEPUBLISHEDDATASETRESPONSE = DESCRIPTOR.message_types_by_name['RemovePublishedDatasetResponse']
_CREATECONFIGURATIONCOMMITREQUEST = DESCRIPTOR.message_types_by_name['CreateConfigurationCommitRequest']
_CREATECONFIGURATIONCOMMITRESPONSE = DESCRIPTOR.message_types_by_name['CreateConfigurationCommitResponse']
_GENERATEMERGEAPPROVALSIGNATUREREQUEST = DESCRIPTOR.message_types_by_name['GenerateMergeApprovalSignatureRequest']
_GENERATEMERGEAPPROVALSIGNATURERESPONSE = DESCRIPTOR.message_types_by_name['GenerateMergeApprovalSignatureResponse']
_MERGECONFIGURATIONCOMMITREQUEST = DESCRIPTOR.message_types_by_name['MergeConfigurationCommitRequest']
_MERGECONFIGURATIONCOMMITREQUEST_APPROVALSIGNATURESENTRY = _MERGECONFIGURATIONCOMMITREQUEST.nested_types_by_name['ApprovalSignaturesEntry']
_RETRIEVEDATAROOMCONFIGURATIONHISTORYREQUEST = DESCRIPTOR.message_types_by_name['RetrieveDataRoomConfigurationHistoryRequest']
_RETRIEVEDATAROOMCONFIGURATIONHISTORYRESPONSE = DESCRIPTOR.message_types_by_name['RetrieveDataRoomConfigurationHistoryResponse']
_RETRIEVECONFIGURATIONCOMMITAPPROVERSREQUEST = DESCRIPTOR.message_types_by_name['RetrieveConfigurationCommitApproversRequest']
_RETRIEVECONFIGURATIONCOMMITAPPROVERSRESPONSE = DESCRIPTOR.message_types_by_name['RetrieveConfigurationCommitApproversResponse']
_RETRIEVECONFIGURATIONCOMMITREQUEST = DESCRIPTOR.message_types_by_name['RetrieveConfigurationCommitRequest']
_RETRIEVECONFIGURATIONCOMMITRESPONSE = DESCRIPTOR.message_types_by_name['RetrieveConfigurationCommitResponse']
_MERGECONFIGURATIONCOMMITRESPONSE = DESCRIPTOR.message_types_by_name['MergeConfigurationCommitResponse']
_DRIVERTASKCONFIG = DESCRIPTOR.message_types_by_name['DriverTaskConfig']
_NOOPCONFIG = DESCRIPTOR.message_types_by_name['NoopConfig']
_STATICCONTENTCONFIG = DESCRIPTOR.message_types_by_name['StaticContentConfig']
GcgRequest = _reflection.GeneratedProtocolMessageType('GcgRequest', (_message.Message,), {
  'DESCRIPTOR' : _GCGREQUEST,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.GcgRequest)
  })
_sym_db.RegisterMessage(GcgRequest)

GcgResponse = _reflection.GeneratedProtocolMessageType('GcgResponse', (_message.Message,), {
  'DESCRIPTOR' : _GCGRESPONSE,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.GcgResponse)
  })
_sym_db.RegisterMessage(GcgResponse)

CreateDataRoomRequest = _reflection.GeneratedProtocolMessageType('CreateDataRoomRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEDATAROOMREQUEST,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.CreateDataRoomRequest)
  })
_sym_db.RegisterMessage(CreateDataRoomRequest)

CreateDataRoomResponse = _reflection.GeneratedProtocolMessageType('CreateDataRoomResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEDATAROOMRESPONSE,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.CreateDataRoomResponse)
  })
_sym_db.RegisterMessage(CreateDataRoomResponse)

DataRoomValidationError = _reflection.GeneratedProtocolMessageType('DataRoomValidationError', (_message.Message,), {
  'DESCRIPTOR' : _DATAROOMVALIDATIONERROR,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.DataRoomValidationError)
  })
_sym_db.RegisterMessage(DataRoomValidationError)

PublishDatasetToDataRoomRequest = _reflection.GeneratedProtocolMessageType('PublishDatasetToDataRoomRequest', (_message.Message,), {
  'DESCRIPTOR' : _PUBLISHDATASETTODATAROOMREQUEST,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.PublishDatasetToDataRoomRequest)
  })
_sym_db.RegisterMessage(PublishDatasetToDataRoomRequest)

PublishDatasetToDataRoomResponse = _reflection.GeneratedProtocolMessageType('PublishDatasetToDataRoomResponse', (_message.Message,), {
  'DESCRIPTOR' : _PUBLISHDATASETTODATAROOMRESPONSE,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.PublishDatasetToDataRoomResponse)
  })
_sym_db.RegisterMessage(PublishDatasetToDataRoomResponse)

ExecuteComputeRequest = _reflection.GeneratedProtocolMessageType('ExecuteComputeRequest', (_message.Message,), {
  'DESCRIPTOR' : _EXECUTECOMPUTEREQUEST,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.ExecuteComputeRequest)
  })
_sym_db.RegisterMessage(ExecuteComputeRequest)

ExecuteDevelopmentComputeRequest = _reflection.GeneratedProtocolMessageType('ExecuteDevelopmentComputeRequest', (_message.Message,), {
  'DESCRIPTOR' : _EXECUTEDEVELOPMENTCOMPUTEREQUEST,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.ExecuteDevelopmentComputeRequest)
  })
_sym_db.RegisterMessage(ExecuteDevelopmentComputeRequest)

ExecuteComputeResponse = _reflection.GeneratedProtocolMessageType('ExecuteComputeResponse', (_message.Message,), {
  'DESCRIPTOR' : _EXECUTECOMPUTERESPONSE,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.ExecuteComputeResponse)
  })
_sym_db.RegisterMessage(ExecuteComputeResponse)

JobStatusRequest = _reflection.GeneratedProtocolMessageType('JobStatusRequest', (_message.Message,), {
  'DESCRIPTOR' : _JOBSTATUSREQUEST,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.JobStatusRequest)
  })
_sym_db.RegisterMessage(JobStatusRequest)

JobStatusResponse = _reflection.GeneratedProtocolMessageType('JobStatusResponse', (_message.Message,), {
  'DESCRIPTOR' : _JOBSTATUSRESPONSE,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.JobStatusResponse)
  })
_sym_db.RegisterMessage(JobStatusResponse)

GetResultsRequest = _reflection.GeneratedProtocolMessageType('GetResultsRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETRESULTSREQUEST,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.GetResultsRequest)
  })
_sym_db.RegisterMessage(GetResultsRequest)

GetResultsResponseChunk = _reflection.GeneratedProtocolMessageType('GetResultsResponseChunk', (_message.Message,), {
  'DESCRIPTOR' : _GETRESULTSRESPONSECHUNK,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.GetResultsResponseChunk)
  })
_sym_db.RegisterMessage(GetResultsResponseChunk)

GetResultsResponseFooter = _reflection.GeneratedProtocolMessageType('GetResultsResponseFooter', (_message.Message,), {
  'DESCRIPTOR' : _GETRESULTSRESPONSEFOOTER,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.GetResultsResponseFooter)
  })
_sym_db.RegisterMessage(GetResultsResponseFooter)

RetrieveDataRoomRequest = _reflection.GeneratedProtocolMessageType('RetrieveDataRoomRequest', (_message.Message,), {
  'DESCRIPTOR' : _RETRIEVEDATAROOMREQUEST,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.RetrieveDataRoomRequest)
  })
_sym_db.RegisterMessage(RetrieveDataRoomRequest)

RetrieveDataRoomResponse = _reflection.GeneratedProtocolMessageType('RetrieveDataRoomResponse', (_message.Message,), {
  'DESCRIPTOR' : _RETRIEVEDATAROOMRESPONSE,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.RetrieveDataRoomResponse)
  })
_sym_db.RegisterMessage(RetrieveDataRoomResponse)

RetrieveAuditLogRequest = _reflection.GeneratedProtocolMessageType('RetrieveAuditLogRequest', (_message.Message,), {
  'DESCRIPTOR' : _RETRIEVEAUDITLOGREQUEST,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.RetrieveAuditLogRequest)
  })
_sym_db.RegisterMessage(RetrieveAuditLogRequest)

RetrieveAuditLogResponse = _reflection.GeneratedProtocolMessageType('RetrieveAuditLogResponse', (_message.Message,), {
  'DESCRIPTOR' : _RETRIEVEAUDITLOGRESPONSE,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.RetrieveAuditLogResponse)
  })
_sym_db.RegisterMessage(RetrieveAuditLogResponse)

RetrieveDataRoomStatusRequest = _reflection.GeneratedProtocolMessageType('RetrieveDataRoomStatusRequest', (_message.Message,), {
  'DESCRIPTOR' : _RETRIEVEDATAROOMSTATUSREQUEST,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.RetrieveDataRoomStatusRequest)
  })
_sym_db.RegisterMessage(RetrieveDataRoomStatusRequest)

RetrieveDataRoomStatusResponse = _reflection.GeneratedProtocolMessageType('RetrieveDataRoomStatusResponse', (_message.Message,), {
  'DESCRIPTOR' : _RETRIEVEDATAROOMSTATUSRESPONSE,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.RetrieveDataRoomStatusResponse)
  })
_sym_db.RegisterMessage(RetrieveDataRoomStatusResponse)

UpdateDataRoomStatusRequest = _reflection.GeneratedProtocolMessageType('UpdateDataRoomStatusRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEDATAROOMSTATUSREQUEST,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.UpdateDataRoomStatusRequest)
  })
_sym_db.RegisterMessage(UpdateDataRoomStatusRequest)

UpdateDataRoomStatusResponse = _reflection.GeneratedProtocolMessageType('UpdateDataRoomStatusResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEDATAROOMSTATUSRESPONSE,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.UpdateDataRoomStatusResponse)
  })
_sym_db.RegisterMessage(UpdateDataRoomStatusResponse)

RetrievePublishedDatasetsRequest = _reflection.GeneratedProtocolMessageType('RetrievePublishedDatasetsRequest', (_message.Message,), {
  'DESCRIPTOR' : _RETRIEVEPUBLISHEDDATASETSREQUEST,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.RetrievePublishedDatasetsRequest)
  })
_sym_db.RegisterMessage(RetrievePublishedDatasetsRequest)

PublishedDataset = _reflection.GeneratedProtocolMessageType('PublishedDataset', (_message.Message,), {
  'DESCRIPTOR' : _PUBLISHEDDATASET,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.PublishedDataset)
  })
_sym_db.RegisterMessage(PublishedDataset)

RetrievePublishedDatasetsResponse = _reflection.GeneratedProtocolMessageType('RetrievePublishedDatasetsResponse', (_message.Message,), {
  'DESCRIPTOR' : _RETRIEVEPUBLISHEDDATASETSRESPONSE,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.RetrievePublishedDatasetsResponse)
  })
_sym_db.RegisterMessage(RetrievePublishedDatasetsResponse)

RemovePublishedDatasetRequest = _reflection.GeneratedProtocolMessageType('RemovePublishedDatasetRequest', (_message.Message,), {
  'DESCRIPTOR' : _REMOVEPUBLISHEDDATASETREQUEST,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.RemovePublishedDatasetRequest)
  })
_sym_db.RegisterMessage(RemovePublishedDatasetRequest)

RemovePublishedDatasetResponse = _reflection.GeneratedProtocolMessageType('RemovePublishedDatasetResponse', (_message.Message,), {
  'DESCRIPTOR' : _REMOVEPUBLISHEDDATASETRESPONSE,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.RemovePublishedDatasetResponse)
  })
_sym_db.RegisterMessage(RemovePublishedDatasetResponse)

CreateConfigurationCommitRequest = _reflection.GeneratedProtocolMessageType('CreateConfigurationCommitRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATECONFIGURATIONCOMMITREQUEST,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.CreateConfigurationCommitRequest)
  })
_sym_db.RegisterMessage(CreateConfigurationCommitRequest)

CreateConfigurationCommitResponse = _reflection.GeneratedProtocolMessageType('CreateConfigurationCommitResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATECONFIGURATIONCOMMITRESPONSE,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.CreateConfigurationCommitResponse)
  })
_sym_db.RegisterMessage(CreateConfigurationCommitResponse)

GenerateMergeApprovalSignatureRequest = _reflection.GeneratedProtocolMessageType('GenerateMergeApprovalSignatureRequest', (_message.Message,), {
  'DESCRIPTOR' : _GENERATEMERGEAPPROVALSIGNATUREREQUEST,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.GenerateMergeApprovalSignatureRequest)
  })
_sym_db.RegisterMessage(GenerateMergeApprovalSignatureRequest)

GenerateMergeApprovalSignatureResponse = _reflection.GeneratedProtocolMessageType('GenerateMergeApprovalSignatureResponse', (_message.Message,), {
  'DESCRIPTOR' : _GENERATEMERGEAPPROVALSIGNATURERESPONSE,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.GenerateMergeApprovalSignatureResponse)
  })
_sym_db.RegisterMessage(GenerateMergeApprovalSignatureResponse)

MergeConfigurationCommitRequest = _reflection.GeneratedProtocolMessageType('MergeConfigurationCommitRequest', (_message.Message,), {

  'ApprovalSignaturesEntry' : _reflection.GeneratedProtocolMessageType('ApprovalSignaturesEntry', (_message.Message,), {
    'DESCRIPTOR' : _MERGECONFIGURATIONCOMMITREQUEST_APPROVALSIGNATURESENTRY,
    '__module__' : 'gcg_pb2'
    # @@protoc_insertion_point(class_scope:gcg.MergeConfigurationCommitRequest.ApprovalSignaturesEntry)
    })
  ,
  'DESCRIPTOR' : _MERGECONFIGURATIONCOMMITREQUEST,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.MergeConfigurationCommitRequest)
  })
_sym_db.RegisterMessage(MergeConfigurationCommitRequest)
_sym_db.RegisterMessage(MergeConfigurationCommitRequest.ApprovalSignaturesEntry)

RetrieveDataRoomConfigurationHistoryRequest = _reflection.GeneratedProtocolMessageType('RetrieveDataRoomConfigurationHistoryRequest', (_message.Message,), {
  'DESCRIPTOR' : _RETRIEVEDATAROOMCONFIGURATIONHISTORYREQUEST,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.RetrieveDataRoomConfigurationHistoryRequest)
  })
_sym_db.RegisterMessage(RetrieveDataRoomConfigurationHistoryRequest)

RetrieveDataRoomConfigurationHistoryResponse = _reflection.GeneratedProtocolMessageType('RetrieveDataRoomConfigurationHistoryResponse', (_message.Message,), {
  'DESCRIPTOR' : _RETRIEVEDATAROOMCONFIGURATIONHISTORYRESPONSE,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.RetrieveDataRoomConfigurationHistoryResponse)
  })
_sym_db.RegisterMessage(RetrieveDataRoomConfigurationHistoryResponse)

RetrieveConfigurationCommitApproversRequest = _reflection.GeneratedProtocolMessageType('RetrieveConfigurationCommitApproversRequest', (_message.Message,), {
  'DESCRIPTOR' : _RETRIEVECONFIGURATIONCOMMITAPPROVERSREQUEST,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.RetrieveConfigurationCommitApproversRequest)
  })
_sym_db.RegisterMessage(RetrieveConfigurationCommitApproversRequest)

RetrieveConfigurationCommitApproversResponse = _reflection.GeneratedProtocolMessageType('RetrieveConfigurationCommitApproversResponse', (_message.Message,), {
  'DESCRIPTOR' : _RETRIEVECONFIGURATIONCOMMITAPPROVERSRESPONSE,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.RetrieveConfigurationCommitApproversResponse)
  })
_sym_db.RegisterMessage(RetrieveConfigurationCommitApproversResponse)

RetrieveConfigurationCommitRequest = _reflection.GeneratedProtocolMessageType('RetrieveConfigurationCommitRequest', (_message.Message,), {
  'DESCRIPTOR' : _RETRIEVECONFIGURATIONCOMMITREQUEST,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.RetrieveConfigurationCommitRequest)
  })
_sym_db.RegisterMessage(RetrieveConfigurationCommitRequest)

RetrieveConfigurationCommitResponse = _reflection.GeneratedProtocolMessageType('RetrieveConfigurationCommitResponse', (_message.Message,), {
  'DESCRIPTOR' : _RETRIEVECONFIGURATIONCOMMITRESPONSE,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.RetrieveConfigurationCommitResponse)
  })
_sym_db.RegisterMessage(RetrieveConfigurationCommitResponse)

MergeConfigurationCommitResponse = _reflection.GeneratedProtocolMessageType('MergeConfigurationCommitResponse', (_message.Message,), {
  'DESCRIPTOR' : _MERGECONFIGURATIONCOMMITRESPONSE,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.MergeConfigurationCommitResponse)
  })
_sym_db.RegisterMessage(MergeConfigurationCommitResponse)

DriverTaskConfig = _reflection.GeneratedProtocolMessageType('DriverTaskConfig', (_message.Message,), {
  'DESCRIPTOR' : _DRIVERTASKCONFIG,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.DriverTaskConfig)
  })
_sym_db.RegisterMessage(DriverTaskConfig)

NoopConfig = _reflection.GeneratedProtocolMessageType('NoopConfig', (_message.Message,), {
  'DESCRIPTOR' : _NOOPCONFIG,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.NoopConfig)
  })
_sym_db.RegisterMessage(NoopConfig)

StaticContentConfig = _reflection.GeneratedProtocolMessageType('StaticContentConfig', (_message.Message,), {
  'DESCRIPTOR' : _STATICCONTENTCONFIG,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.StaticContentConfig)
  })
_sym_db.RegisterMessage(StaticContentConfig)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _MERGECONFIGURATIONCOMMITREQUEST_APPROVALSIGNATURESENTRY._options = None
  _MERGECONFIGURATIONCOMMITREQUEST_APPROVALSIGNATURESENTRY._serialized_options = b'8\001'
  _DATAROOMSTATUS._serialized_start=6339
  _DATAROOMSTATUS._serialized_end=6380
  _GCGREQUEST._serialized_start=55
  _GCGREQUEST._serialized_end=1466
  _GCGRESPONSE._serialized_start=1469
  _GCGRESPONSE._serialized_end=2929
  _CREATEDATAROOMREQUEST._serialized_start=2932
  _CREATEDATAROOMREQUEST._serialized_end=3068
  _CREATEDATAROOMRESPONSE._serialized_start=3071
  _CREATEDATAROOMRESPONSE._serialized_end=3211
  _DATAROOMVALIDATIONERROR._serialized_start=3214
  _DATAROOMVALIDATIONERROR._serialized_end=3552
  _PUBLISHDATASETTODATAROOMREQUEST._serialized_start=3555
  _PUBLISHDATASETTODATAROOMREQUEST._serialized_end=3685
  _PUBLISHDATASETTODATAROOMRESPONSE._serialized_start=3687
  _PUBLISHDATASETTODATAROOMRESPONSE._serialized_end=3721
  _EXECUTECOMPUTEREQUEST._serialized_start=3723
  _EXECUTECOMPUTEREQUEST._serialized_end=3825
  _EXECUTEDEVELOPMENTCOMPUTEREQUEST._serialized_start=3827
  _EXECUTEDEVELOPMENTCOMPUTEREQUEST._serialized_end=3951
  _EXECUTECOMPUTERESPONSE._serialized_start=3953
  _EXECUTECOMPUTERESPONSE._serialized_end=3992
  _JOBSTATUSREQUEST._serialized_start=3994
  _JOBSTATUSREQUEST._serialized_end=4027
  _JOBSTATUSRESPONSE._serialized_start=4029
  _JOBSTATUSRESPONSE._serialized_end=4082
  _GETRESULTSREQUEST._serialized_start=4084
  _GETRESULTSREQUEST._serialized_end=4143
  _GETRESULTSRESPONSECHUNK._serialized_start=4145
  _GETRESULTSRESPONSECHUNK._serialized_end=4184
  _GETRESULTSRESPONSEFOOTER._serialized_start=4186
  _GETRESULTSRESPONSEFOOTER._serialized_end=4212
  _RETRIEVEDATAROOMREQUEST._serialized_start=4214
  _RETRIEVEDATAROOMREQUEST._serialized_end=4265
  _RETRIEVEDATAROOMRESPONSE._serialized_start=4267
  _RETRIEVEDATAROOMRESPONSE._serialized_end=4332
  _RETRIEVEAUDITLOGREQUEST._serialized_start=4334
  _RETRIEVEAUDITLOGREQUEST._serialized_end=4394
  _RETRIEVEAUDITLOGRESPONSE._serialized_start=4396
  _RETRIEVEAUDITLOGRESPONSE._serialized_end=4435
  _RETRIEVEDATAROOMSTATUSREQUEST._serialized_start=4437
  _RETRIEVEDATAROOMSTATUSREQUEST._serialized_end=4503
  _RETRIEVEDATAROOMSTATUSRESPONSE._serialized_start=4505
  _RETRIEVEDATAROOMSTATUSRESPONSE._serialized_end=4574
  _UPDATEDATAROOMSTATUSREQUEST._serialized_start=4576
  _UPDATEDATAROOMSTATUSREQUEST._serialized_end=4677
  _UPDATEDATAROOMSTATUSRESPONSE._serialized_start=4679
  _UPDATEDATAROOMSTATUSRESPONSE._serialized_end=4709
  _RETRIEVEPUBLISHEDDATASETSREQUEST._serialized_start=4711
  _RETRIEVEPUBLISHEDDATASETSREQUEST._serialized_end=4780
  _PUBLISHEDDATASET._serialized_start=4782
  _PUBLISHEDDATASET._serialized_end=4872
  _RETRIEVEPUBLISHEDDATASETSRESPONSE._serialized_start=4874
  _RETRIEVEPUBLISHEDDATASETSRESPONSE._serialized_end=4959
  _REMOVEPUBLISHEDDATASETREQUEST._serialized_start=4961
  _REMOVEPUBLISHEDDATASETREQUEST._serialized_end=5051
  _REMOVEPUBLISHEDDATASETRESPONSE._serialized_start=5053
  _REMOVEPUBLISHEDDATASETRESPONSE._serialized_end=5085
  _CREATECONFIGURATIONCOMMITREQUEST._serialized_start=5087
  _CREATECONFIGURATIONCOMMITREQUEST._serialized_end=5184
  _CREATECONFIGURATIONCOMMITRESPONSE._serialized_start=5186
  _CREATECONFIGURATIONCOMMITRESPONSE._serialized_end=5239
  _GENERATEMERGEAPPROVALSIGNATUREREQUEST._serialized_start=5241
  _GENERATEMERGEAPPROVALSIGNATUREREQUEST._serialized_end=5313
  _GENERATEMERGEAPPROVALSIGNATURERESPONSE._serialized_start=5315
  _GENERATEMERGEAPPROVALSIGNATURERESPONSE._serialized_end=5374
  _MERGECONFIGURATIONCOMMITREQUEST._serialized_start=5377
  _MERGECONFIGURATIONCOMMITREQUEST._serialized_end=5592
  _MERGECONFIGURATIONCOMMITREQUEST_APPROVALSIGNATURESENTRY._serialized_start=5535
  _MERGECONFIGURATIONCOMMITREQUEST_APPROVALSIGNATURESENTRY._serialized_end=5592
  _RETRIEVEDATAROOMCONFIGURATIONHISTORYREQUEST._serialized_start=5594
  _RETRIEVEDATAROOMCONFIGURATIONHISTORYREQUEST._serialized_end=5659
  _RETRIEVEDATAROOMCONFIGURATIONHISTORYRESPONSE._serialized_start=5662
  _RETRIEVEDATAROOMCONFIGURATIONHISTORYRESPONSE._serialized_end=5816
  _RETRIEVECONFIGURATIONCOMMITAPPROVERSREQUEST._serialized_start=5818
  _RETRIEVECONFIGURATIONCOMMITAPPROVERSREQUEST._serialized_end=5896
  _RETRIEVECONFIGURATIONCOMMITAPPROVERSRESPONSE._serialized_start=5898
  _RETRIEVECONFIGURATIONCOMMITAPPROVERSRESPONSE._serialized_end=5963
  _RETRIEVECONFIGURATIONCOMMITREQUEST._serialized_start=5965
  _RETRIEVECONFIGURATIONCOMMITREQUEST._serialized_end=6034
  _RETRIEVECONFIGURATIONCOMMITRESPONSE._serialized_start=6036
  _RETRIEVECONFIGURATIONCOMMITRESPONSE._serialized_end=6121
  _MERGECONFIGURATIONCOMMITRESPONSE._serialized_start=6123
  _MERGECONFIGURATIONCOMMITRESPONSE._serialized_end=6157
  _DRIVERTASKCONFIG._serialized_start=6159
  _DRIVERTASKCONFIG._serialized_end=6283
  _NOOPCONFIG._serialized_start=6285
  _NOOPCONFIG._serialized_end=6297
  _STATICCONTENTCONFIG._serialized_start=6299
  _STATICCONTENTCONFIG._serialized_end=6337
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: data_room.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import attestation_pb2 as attestation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0f\x64\x61ta_room.proto\x12\tdata_room\x1a\x11\x61ttestation.proto\"\x8e\x01\n\x08\x44\x61taRoom\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x06 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x07 \x01(\t\x12\x12\n\nownerEmail\x18\x08 \x01(\t\x12\x39\n\x12governanceProtocol\x18\t \x01(\x0b\x32\x1d.data_room.GovernanceProtocolJ\x04\x08\x02\x10\x06\"\xb6\x01\n\x12GovernanceProtocol\x12?\n\x14staticDataRoomPolicy\x18\x01 \x01(\x0b\x32\x1f.data_room.StaticDataRoomPolicyH\x00\x12U\n\x1f\x61\x66\x66\x65\x63tedDataOwnersApprovePolicy\x18\x02 \x01(\x0b\x32*.data_room.AffectedDataOwnersApprovePolicyH\x00\x42\x08\n\x06policy\"\x16\n\x14StaticDataRoomPolicy\"!\n\x1f\x41\x66\x66\x65\x63tedDataOwnersApprovePolicy\"\xab\x01\n\x15\x44\x61taRoomConfiguration\x12@\n\x08\x65lements\x18\x01 \x03(\x0b\x32..data_room.DataRoomConfiguration.ElementsEntry\x1aP\n\rElementsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12.\n\x05value\x18\x02 \x01(\x0b\x32\x1f.data_room.ConfigurationElement:\x02\x38\x01\"\x91\x02\n\x14\x43onfigurationElement\x12-\n\x0b\x63omputeNode\x18\x01 \x01(\x0b\x32\x16.data_room.ComputeNodeH\x00\x12I\n\x18\x61ttestationSpecification\x18\x02 \x01(\x0b\x32%.attestation.AttestationSpecificationH\x00\x12\x33\n\x0euserPermission\x18\x03 \x01(\x0b\x32\x19.data_room.UserPermissionH\x00\x12?\n\x14\x61uthenticationMethod\x18\x04 \x01(\x0b\x32\x1f.data_room.AuthenticationMethodH\x00\x42\t\n\x07\x65lement\"\xb8\x01\n\x19\x43onfigurationModification\x12)\n\x03\x61\x64\x64\x18\x01 \x01(\x0b\x32\x1a.data_room.AddModificationH\x00\x12/\n\x06\x63hange\x18\x02 \x01(\x0b\x32\x1d.data_room.ChangeModificationH\x00\x12/\n\x06\x64\x65lete\x18\x03 \x01(\x0b\x32\x1d.data_room.DeleteModificationH\x00\x42\x0e\n\x0cmodification\"O\n\x0f\x41\x64\x64Modification\x12\n\n\x02id\x18\x01 \x01(\t\x12\x30\n\x07\x65lement\x18\x02 \x01(\x0b\x32\x1f.data_room.ConfigurationElement\"R\n\x12\x43hangeModification\x12\n\n\x02id\x18\x01 \x01(\t\x12\x30\n\x07\x65lement\x18\x02 \x01(\x0b\x32\x1f.data_room.ConfigurationElement\" \n\x12\x44\x65leteModification\x12\n\n\x02id\x18\x01 \x01(\t\"\x82\x01\n\x13\x43onfigurationCommit\x12\x12\n\ndataRoomId\x18\x01 \x01(\x0c\x12\x1a\n\x12\x64\x61taRoomHistoryPin\x18\x02 \x01(\x0c\x12;\n\rmodifications\x18\x03 \x03(\x0b\x32$.data_room.ConfigurationModification\"\x83\x01\n\x0b\x43omputeNode\x12\x10\n\x08nodeName\x18\x01 \x01(\t\x12*\n\x04leaf\x18\x02 \x01(\x0b\x32\x1a.data_room.ComputeNodeLeafH\x00\x12.\n\x06\x62ranch\x18\x03 \x01(\x0b\x32\x1c.data_room.ComputeNodeBranchH\x00\x42\x06\n\x04node\"%\n\x0f\x43omputeNodeLeaf\x12\x12\n\nisRequired\x18\x01 \x01(\x08\"&\n\x13\x43omputeNodeProtocol\x12\x0f\n\x07version\x18\x01 \x01(\r\"\xc9\x01\n\x11\x43omputeNodeBranch\x12\x0e\n\x06\x63onfig\x18\x01 \x01(\x0c\x12\x14\n\x0c\x64\x65pendencies\x18\x02 \x03(\t\x12\x32\n\x0coutputFormat\x18\x04 \x01(\x0e\x32\x1c.data_room.ComputeNodeFormat\x12\x30\n\x08protocol\x18\x05 \x01(\x0b\x32\x1e.data_room.ComputeNodeProtocol\x12\"\n\x1a\x61ttestationSpecificationId\x18\x06 \x01(\tJ\x04\x08\x03\x10\x04\"q\n\x0eUserPermission\x12\r\n\x05\x65mail\x18\x01 \x01(\t\x12*\n\x0bpermissions\x18\x03 \x03(\x0b\x32\x15.data_room.Permission\x12\x1e\n\x16\x61uthenticationMethodId\x18\x04 \x01(\tJ\x04\x08\x02\x10\x03\"U\n\x14\x41uthenticationMethod\x12.\n\ntrustedPki\x18\x01 \x01(\x0b\x32\x15.data_room.TrustedPkiH\x00\x88\x01\x01\x42\r\n\x0b_trustedPki\"(\n\nTrustedPki\x12\x1a\n\x12rootCertificatePem\x18\x01 \x01(\x0c\"\x95\x07\n\nPermission\x12G\n\x18\x65xecuteComputePermission\x18\x01 \x01(\x0b\x32#.data_room.ExecuteComputePermissionH\x00\x12;\n\x12leafCrudPermission\x18\x02 \x01(\x0b\x32\x1d.data_room.LeafCrudPermissionH\x00\x12K\n\x1aretrieveDataRoomPermission\x18\x03 \x01(\x0b\x32%.data_room.RetrieveDataRoomPermissionH\x00\x12K\n\x1aretrieveAuditLogPermission\x18\x04 \x01(\x0b\x32%.data_room.RetrieveAuditLogPermissionH\x00\x12W\n retrieveDataRoomStatusPermission\x18\x05 \x01(\x0b\x32+.data_room.RetrieveDataRoomStatusPermissionH\x00\x12S\n\x1eupdateDataRoomStatusPermission\x18\x06 \x01(\x0b\x32).data_room.UpdateDataRoomStatusPermissionH\x00\x12]\n#retrievePublishedDatasetsPermission\x18\x07 \x01(\x0b\x32..data_room.RetrievePublishedDatasetsPermissionH\x00\x12\x37\n\x10\x64ryRunPermission\x18\x08 \x01(\x0b\x32\x1b.data_room.DryRunPermissionH\x00\x12W\n generateMergeSignaturePermission\x18\t \x01(\x0b\x32+.data_room.GenerateMergeSignaturePermissionH\x00\x12]\n#executeDevelopmentComputePermission\x18\n \x01(\x0b\x32..data_room.ExecuteDevelopmentComputePermissionH\x00\x12[\n\"mergeConfigurationCommitPermission\x18\x0b \x01(\x0b\x32-.data_room.MergeConfigurationCommitPermissionH\x00\x42\x0c\n\npermission\"3\n\x18\x45xecuteComputePermission\x12\x17\n\x0f\x63omputeNodeName\x18\x01 \x01(\t\"*\n\x12LeafCrudPermission\x12\x14\n\x0cleafNodeName\x18\x01 \x01(\t\"\x1c\n\x1aRetrieveDataRoomPermission\"\x1c\n\x1aRetrieveAuditLogPermission\"\"\n RetrieveDataRoomStatusPermission\" \n\x1eUpdateDataRoomStatusPermission\"%\n#RetrievePublishedDatasetsPermission\"\x12\n\x10\x44ryRunPermission\"\"\n GenerateMergeSignaturePermission\"%\n#ExecuteDevelopmentComputePermission\"$\n\"MergeConfigurationCommitPermission*%\n\x11\x43omputeNodeFormat\x12\x07\n\x03RAW\x10\x00\x12\x07\n\x03ZIP\x10\x01\x62\x06proto3')

_COMPUTENODEFORMAT = DESCRIPTOR.enum_types_by_name['ComputeNodeFormat']
ComputeNodeFormat = enum_type_wrapper.EnumTypeWrapper(_COMPUTENODEFORMAT)
RAW = 0
ZIP = 1


_DATAROOM = DESCRIPTOR.message_types_by_name['DataRoom']
_GOVERNANCEPROTOCOL = DESCRIPTOR.message_types_by_name['GovernanceProtocol']
_STATICDATAROOMPOLICY = DESCRIPTOR.message_types_by_name['StaticDataRoomPolicy']
_AFFECTEDDATAOWNERSAPPROVEPOLICY = DESCRIPTOR.message_types_by_name['AffectedDataOwnersApprovePolicy']
_DATAROOMCONFIGURATION = DESCRIPTOR.message_types_by_name['DataRoomConfiguration']
_DATAROOMCONFIGURATION_ELEMENTSENTRY = _DATAROOMCONFIGURATION.nested_types_by_name['ElementsEntry']
_CONFIGURATIONELEMENT = DESCRIPTOR.message_types_by_name['ConfigurationElement']
_CONFIGURATIONMODIFICATION = DESCRIPTOR.message_types_by_name['ConfigurationModification']
_ADDMODIFICATION = DESCRIPTOR.message_types_by_name['AddModification']
_CHANGEMODIFICATION = DESCRIPTOR.message_types_by_name['ChangeModification']
_DELETEMODIFICATION = DESCRIPTOR.message_types_by_name['DeleteModification']
_CONFIGURATIONCOMMIT = DESCRIPTOR.message_types_by_name['ConfigurationCommit']
_COMPUTENODE = DESCRIPTOR.message_types_by_name['ComputeNode']
_COMPUTENODELEAF = DESCRIPTOR.message_types_by_name['ComputeNodeLeaf']
_COMPUTENODEPROTOCOL = DESCRIPTOR.message_types_by_name['ComputeNodeProtocol']
_COMPUTENODEBRANCH = DESCRIPTOR.message_types_by_name['ComputeNodeBranch']
_USERPERMISSION = DESCRIPTOR.message_types_by_name['UserPermission']
_AUTHENTICATIONMETHOD = DESCRIPTOR.message_types_by_name['AuthenticationMethod']
_TRUSTEDPKI = DESCRIPTOR.message_types_by_name['TrustedPki']
_PERMISSION = DESCRIPTOR.message_types_by_name['Permission']
_EXECUTECOMPUTEPERMISSION = DESCRIPTOR.message_types_by_name['ExecuteComputePermission']
_LEAFCRUDPERMISSION = DESCRIPTOR.message_types_by_name['LeafCrudPermission']
_RETRIEVEDATAROOMPERMISSION = DESCRIPTOR.message_types_by_name['RetrieveDataRoomPermission']
_RETRIEVEAUDITLOGPERMISSION = DESCRIPTOR.message_types_by_name['RetrieveAuditLogPermission']
_RETRIEVEDATAROOMSTATUSPERMISSION = DESCRIPTOR.message_types_by_name['RetrieveDataRoomStatusPermission']
_UPDATEDATAROOMSTATUSPERMISSION = DESCRIPTOR.message_types_by_name['UpdateDataRoomStatusPermission']
_RETRIEVEPUBLISHEDDATASETSPERMISSION = DESCRIPTOR.message_types_by_name['RetrievePublishedDatasetsPermission']
_DRYRUNPERMISSION = DESCRIPTOR.message_types_by_name['DryRunPermission']
_GENERATEMERGESIGNATUREPERMISSION = DESCRIPTOR.message_types_by_name['GenerateMergeSignaturePermission']
_EXECUTEDEVELOPMENTCOMPUTEPERMISSION = DESCRIPTOR.message_types_by_name['ExecuteDevelopmentComputePermission']
_MERGECONFIGURATIONCOMMITPERMISSION = DESCRIPTOR.message_types_by_name['MergeConfigurationCommitPermission']
DataRoom = _reflection.GeneratedProtocolMessageType('DataRoom', (_message.Message,), {
  'DESCRIPTOR' : _DATAROOM,
  '__module__' : 'data_room_pb2'
  # @@protoc_insertion_point(class_scope:data_room.DataRoom)
  })
_sym_db.RegisterMessage(DataRoom)

GovernanceProtocol = _reflection.GeneratedProtocolMessageType('GovernanceProtocol', (_message.Message,), {
  'DESCRIPTOR' : _GOVERNANCEPROTOCOL,
  '__module__' : 'data_room_pb2'
  # @@protoc_insertion_point(class_scope:data_room.GovernanceProtocol)
  })
_sym_db.RegisterMessage(GovernanceProtocol)

StaticDataRoomPolicy = _reflection.GeneratedProtocolMessageType('StaticDataRoomPolicy', (_message.Message,), {
  'DESCRIPTOR' : _STATICDATAROOMPOLICY,
  '__module__' : 'data_room_pb2'
  # @@protoc_insertion_point(class_scope:data_room.StaticDataRoomPolicy)
  })
_sym_db.RegisterMessage(StaticDataRoomPolicy)

AffectedDataOwnersApprovePolicy = _reflection.GeneratedProtocolMessageType('AffectedDataOwnersApprovePolicy', (_message.Message,), {
  'DESCRIPTOR' : _AFFECTEDDATAOWNERSAPPROVEPOLICY,
  '__module__' : 'data_room_pb2'
  # @@protoc_insertion_point(class_scope:data_room.AffectedDataOwnersApprovePolicy)
  })
_sym_db.RegisterMessage(AffectedDataOwnersApprovePolicy)

DataRoomConfiguration = _reflection.GeneratedProtocolMessageType('DataRoomConfiguration', (_message.Message,), {

  'ElementsEntry' : _reflection.GeneratedProtocolMessageType('ElementsEntry', (_message.Message,), {
    'DESCRIPTOR' : _DATAROOMCONFIGURATION_ELEMENTSENTRY,
    '__module__' : 'data_room_pb2'
    # @@protoc_insertion_point(class_scope:data_room.DataRoomConfiguration.ElementsEntry)
    })
  ,
  'DESCRIPTOR' : _DATAROOMCONFIGURATION,
  '__module__' : 'data_room_pb2'
  # @@protoc_insertion_point(class_scope:data_room.DataRoomConfiguration)
  })
_sym_db.RegisterMessage(DataRoomConfiguration)
_sym_db.RegisterMessage(DataRoomConfiguration.ElementsEntry)

ConfigurationElement = _reflection.GeneratedProtocolMessageType('ConfigurationElement', (_message.Message,), {
  'DESCRIPTOR' : _CONFIGURATIONELEMENT,
  '__module__' : 'data_room_pb2'
  # @@protoc_insertion_point(class_scope:data_room.ConfigurationElement)
  })
_sym_db.RegisterMessage(ConfigurationElement)

ConfigurationModification = _reflection.GeneratedProtocolMessageType('ConfigurationModification', (_message.Message,), {
  'DESCRIPTOR' : _CONFIGURATIONMODIFICATION,
  '__module__' : 'data_room_pb2'
  # @@protoc_insertion_point(class_scope:data_room.ConfigurationModification)
  })
_sym_db.RegisterMessage(ConfigurationModification)

AddModification = _reflection.GeneratedProtocolMessageType('AddModification', (_message.Message,), {
  'DESCRIPTOR' : _ADDMODIFICATION,
  '__module__' : 'data_room_pb2'
  # @@protoc_insertion_point(class_scope:data_room.AddModification)
  })
_sym_db.RegisterMessage(AddModification)

ChangeModification = _reflection.GeneratedProtocolMessageType('ChangeModification', (_message.Message,), {
  'DESCRIPTOR' : _CHANGEMODIFICATION,
  '__module__' : 'data_room_pb2'
  # @@protoc_insertion_point(class_scope:data_room.ChangeModification)
  })
_sym_db.RegisterMessage(ChangeModification)

DeleteModification = _reflection.GeneratedProtocolMessageType('DeleteModification', (_message.Message,), {
  'DESCRIPTOR' : _DELETEMODIFICATION,
  '__module__' : 'data_room_pb2'
  # @@protoc_insertion_point(class_scope:data_room.DeleteModification)
  })
_sym_db.RegisterMessage(DeleteModification)

ConfigurationCommit = _reflection.GeneratedProtocolMessageType('ConfigurationCommit', (_message.Message,), {
  'DESCRIPTOR' : _CONFIGURATIONCOMMIT,
  '__module__' : 'data_room_pb2'
  # @@protoc_insertion_point(class_scope:data_room.ConfigurationCommit)
  })
_sym_db.RegisterMessage(ConfigurationCommit)

ComputeNode = _reflection.GeneratedProtocolMessageType('ComputeNode', (_message.Message,), {
  'DESCRIPTOR' : _COMPUTENODE,
  '__module__' : 'data_room_pb2'
  # @@protoc_insertion_point(class_scope:data_room.ComputeNode)
  })
_sym_db.RegisterMessage(ComputeNode)

ComputeNodeLeaf = _reflection.GeneratedProtocolMessageType('ComputeNodeLeaf', (_message.Message,), {
  'DESCRIPTOR' : _COMPUTENODELEAF,
  '__module__' : 'data_room_pb2'
  # @@protoc_insertion_point(class_scope:data_room.ComputeNodeLeaf)
  })
_sym_db.RegisterMessage(ComputeNodeLeaf)

ComputeNodeProtocol = _reflection.GeneratedProtocolMessageType('ComputeNodeProtocol', (_message.Message,), {
  'DESCRIPTOR' : _COMPUTENODEPROTOCOL,
  '__module__' : 'data_room_pb2'
  # @@protoc_insertion_point(class_scope:data_room.ComputeNodeProtocol)
  })
_sym_db.RegisterMessage(ComputeNodeProtocol)

ComputeNodeBranch = _reflection.GeneratedProtocolMessageType('ComputeNodeBranch', (_message.Message,), {
  'DESCRIPTOR' : _COMPUTENODEBRANCH,
  '__module__' : 'data_room_pb2'
  # @@protoc_insertion_point(class_scope:data_room.ComputeNodeBranch)
  })
_sym_db.RegisterMessage(ComputeNodeBranch)

UserPermission = _reflection.GeneratedProtocolMessageType('UserPermission', (_message.Message,), {
  'DESCRIPTOR' : _USERPERMISSION,
  '__module__' : 'data_room_pb2'
  # @@protoc_insertion_point(class_scope:data_room.UserPermission)
  })
_sym_db.RegisterMessage(UserPermission)

AuthenticationMethod = _reflection.GeneratedProtocolMessageType('AuthenticationMethod', (_message.Message,), {
  'DESCRIPTOR' : _AUTHENTICATIONMETHOD,
  '__module__' : 'data_room_pb2'
  # @@protoc_insertion_point(class_scope:data_room.AuthenticationMethod)
  })
_sym_db.RegisterMessage(AuthenticationMethod)

TrustedPki = _reflection.GeneratedProtocolMessageType('TrustedPki', (_message.Message,), {
  'DESCRIPTOR' : _TRUSTEDPKI,
  '__module__' : 'data_room_pb2'
  # @@protoc_insertion_point(class_scope:data_room.TrustedPki)
  })
_sym_db.RegisterMessage(TrustedPki)

Permission = _reflection.GeneratedProtocolMessageType('Permission', (_message.Message,), {
  'DESCRIPTOR' : _PERMISSION,
  '__module__' : 'data_room_pb2'
  # @@protoc_insertion_point(class_scope:data_room.Permission)
  })
_sym_db.RegisterMessage(Permission)

ExecuteComputePermission = _reflection.GeneratedProtocolMessageType('ExecuteComputePermission', (_message.Message,), {
  'DESCRIPTOR' : _EXECUTECOMPUTEPERMISSION,
  '__module__' : 'data_room_pb2'
  # @@protoc_insertion_point(class_scope:data_room.ExecuteComputePermission)
  })
_sym_db.RegisterMessage(ExecuteComputePermission)

LeafCrudPermission = _reflection.GeneratedProtocolMessageType('LeafCrudPermission', (_message.Message,), {
  'DESCRIPTOR' : _LEAFCRUDPERMISSION,
  '__module__' : 'data_room_pb2'
  # @@protoc_insertion_point(class_scope:data_room.LeafCrudPermission)
  })
_sym_db.RegisterMessage(LeafCrudPermission)

RetrieveDataRoomPermission = _reflection.GeneratedProtocolMessageType('RetrieveDataRoomPermission', (_message.Message,), {
  'DESCRIPTOR' : _RETRIEVEDATAROOMPERMISSION,
  '__module__' : 'data_room_pb2'
  # @@protoc_insertion_point(class_scope:data_room.RetrieveDataRoomPermission)
  })
_sym_db.RegisterMessage(RetrieveDataRoomPermission)

RetrieveAuditLogPermission = _reflection.GeneratedProtocolMessageType('RetrieveAuditLogPermission', (_message.Message,), {
  'DESCRIPTOR' : _RETRIEVEAUDITLOGPERMISSION,
  '__module__' : 'data_room_pb2'
  # @@protoc_insertion_point(class_scope:data_room.RetrieveAuditLogPermission)
  })
_sym_db.RegisterMessage(RetrieveAuditLogPermission)

RetrieveDataRoomStatusPermission = _reflection.GeneratedProtocolMessageType('RetrieveDataRoomStatusPermission', (_message.Message,), {
  'DESCRIPTOR' : _RETRIEVEDATAROOMSTATUSPERMISSION,
  '__module__' : 'data_room_pb2'
  # @@protoc_insertion_point(class_scope:data_room.RetrieveDataRoomStatusPermission)
  })
_sym_db.RegisterMessage(RetrieveDataRoomStatusPermission)

UpdateDataRoomStatusPermission = _reflection.GeneratedProtocolMessageType('UpdateDataRoomStatusPermission', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEDATAROOMSTATUSPERMISSION,
  '__module__' : 'data_room_pb2'
  # @@protoc_insertion_point(class_scope:data_room.UpdateDataRoomStatusPermission)
  })
_sym_db.RegisterMessage(UpdateDataRoomStatusPermission)

RetrievePublishedDatasetsPermission = _reflection.GeneratedProtocolMessageType('RetrievePublishedDatasetsPermission', (_message.Message,), {
  'DESCRIPTOR' : _RETRIEVEPUBLISHEDDATASETSPERMISSION,
  '__module__' : 'data_room_pb2'
  # @@protoc_insertion_point(class_scope:data_room.RetrievePublishedDatasetsPermission)
  })
_sym_db.RegisterMessage(RetrievePublishedDatasetsPermission)

DryRunPermission = _reflection.GeneratedProtocolMessageType('DryRunPermission', (_message.Message,), {
  'DESCRIPTOR' : _DRYRUNPERMISSION,
  '__module__' : 'data_room_pb2'
  # @@protoc_insertion_point(class_scope:data_room.DryRunPermission)
  })
_sym_db.RegisterMessage(DryRunPermission)

GenerateMergeSignaturePermission = _reflection.GeneratedProtocolMessageType('GenerateMergeSignaturePermission', (_message.Message,), {
  'DESCRIPTOR' : _GENERATEMERGESIGNATUREPERMISSION,
  '__module__' : 'data_room_pb2'
  # @@protoc_insertion_point(class_scope:data_room.GenerateMergeSignaturePermission)
  })
_sym_db.RegisterMessage(GenerateMergeSignaturePermission)

ExecuteDevelopmentComputePermission = _reflection.GeneratedProtocolMessageType('ExecuteDevelopmentComputePermission', (_message.Message,), {
  'DESCRIPTOR' : _EXECUTEDEVELOPMENTCOMPUTEPERMISSION,
  '__module__' : 'data_room_pb2'
  # @@protoc_insertion_point(class_scope:data_room.ExecuteDevelopmentComputePermission)
  })
_sym_db.RegisterMessage(ExecuteDevelopmentComputePermission)

MergeConfigurationCommitPermission = _reflection.GeneratedProtocolMessageType('MergeConfigurationCommitPermission', (_message.Message,), {
  'DESCRIPTOR' : _MERGECONFIGURATIONCOMMITPERMISSION,
  '__module__' : 'data_room_pb2'
  # @@protoc_insertion_point(class_scope:data_room.MergeConfigurationCommitPermission)
  })
_sym_db.RegisterMessage(MergeConfigurationCommitPermission)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _DATAROOMCONFIGURATION_ELEMENTSENTRY._options = None
  _DATAROOMCONFIGURATION_ELEMENTSENTRY._serialized_options = b'8\001'
  _COMPUTENODEFORMAT._serialized_start=3387
  _COMPUTENODEFORMAT._serialized_end=3424
  _DATAROOM._serialized_start=50
  _DATAROOM._serialized_end=192
  _GOVERNANCEPROTOCOL._serialized_start=195
  _GOVERNANCEPROTOCOL._serialized_end=377
  _STATICDATAROOMPOLICY._serialized_start=379
  _STATICDATAROOMPOLICY._serialized_end=401
  _AFFECTEDDATAOWNERSAPPROVEPOLICY._serialized_start=403
  _AFFECTEDDATAOWNERSAPPROVEPOLICY._serialized_end=436
  _DATAROOMCONFIGURATION._serialized_start=439
  _DATAROOMCONFIGURATION._serialized_end=610
  _DATAROOMCONFIGURATION_ELEMENTSENTRY._serialized_start=530
  _DATAROOMCONFIGURATION_ELEMENTSENTRY._serialized_end=610
  _CONFIGURATIONELEMENT._serialized_start=613
  _CONFIGURATIONELEMENT._serialized_end=886
  _CONFIGURATIONMODIFICATION._serialized_start=889
  _CONFIGURATIONMODIFICATION._serialized_end=1073
  _ADDMODIFICATION._serialized_start=1075
  _ADDMODIFICATION._serialized_end=1154
  _CHANGEMODIFICATION._serialized_start=1156
  _CHANGEMODIFICATION._serialized_end=1238
  _DELETEMODIFICATION._serialized_start=1240
  _DELETEMODIFICATION._serialized_end=1272
  _CONFIGURATIONCOMMIT._serialized_start=1275
  _CONFIGURATIONCOMMIT._serialized_end=1405
  _COMPUTENODE._serialized_start=1408
  _COMPUTENODE._serialized_end=1539
  _COMPUTENODELEAF._serialized_start=1541
  _COMPUTENODELEAF._serialized_end=1578
  _COMPUTENODEPROTOCOL._serialized_start=1580
  _COMPUTENODEPROTOCOL._serialized_end=1618
  _COMPUTENODEBRANCH._serialized_start=1621
  _COMPUTENODEBRANCH._serialized_end=1822
  _USERPERMISSION._serialized_start=1824
  _USERPERMISSION._serialized_end=1937
  _AUTHENTICATIONMETHOD._serialized_start=1939
  _AUTHENTICATIONMETHOD._serialized_end=2024
  _TRUSTEDPKI._serialized_start=2026
  _TRUSTEDPKI._serialized_end=2066
  _PERMISSION._serialized_start=2069
  _PERMISSION._serialized_end=2986
  _EXECUTECOMPUTEPERMISSION._serialized_start=2988
  _EXECUTECOMPUTEPERMISSION._serialized_end=3039
  _LEAFCRUDPERMISSION._serialized_start=3041
  _LEAFCRUDPERMISSION._serialized_end=3083
  _RETRIEVEDATAROOMPERMISSION._serialized_start=3085
  _RETRIEVEDATAROOMPERMISSION._serialized_end=3113
  _RETRIEVEAUDITLOGPERMISSION._serialized_start=3115
  _RETRIEVEAUDITLOGPERMISSION._serialized_end=3143
  _RETRIEVEDATAROOMSTATUSPERMISSION._serialized_start=3145
  _RETRIEVEDATAROOMSTATUSPERMISSION._serialized_end=3179
  _UPDATEDATAROOMSTATUSPERMISSION._serialized_start=3181
  _UPDATEDATAROOMSTATUSPERMISSION._serialized_end=3213
  _RETRIEVEPUBLISHEDDATASETSPERMISSION._serialized_start=3215
  _RETRIEVEPUBLISHEDDATASETSPERMISSION._serialized_end=3252
  _DRYRUNPERMISSION._serialized_start=3254
  _DRYRUNPERMISSION._serialized_end=3272
  _GENERATEMERGESIGNATUREPERMISSION._serialized_start=3274
  _GENERATEMERGESIGNATUREPERMISSION._serialized_end=3308
  _EXECUTEDEVELOPMENTCOMPUTEPERMISSION._serialized_start=3310
  _EXECUTEDEVELOPMENTCOMPUTEPERMISSION._serialized_end=3347
  _MERGECONFIGURATIONCOMMITPERMISSION._serialized_start=3349
  _MERGECONFIGURATIONCOMMITPERMISSION._serialized_end=3385
# @@protoc_insertion_point(module_scope)
